@@ -15,7 +15,8 @@ void CWS_to_PermCWS(CWS *Cin, CWS *C, int *pi);
 
 int  IsNextDigit(){    
   char c; c=fgetc(inFILE); ungetc(c,inFILE);
-  if(c=='0') return -1; if((c<'0') || ('9'<c)) return 0; else return 1;
+  if(c=='0') return -1;
+  if((c<'0') || ('9'<c)) return 0; else return 1;
 }
 
 void Print_PPL(PolyPointList *_P, const char *comment){
@@ -65,7 +66,8 @@ void Print_Matrix(Long Matrix[][VERT_Nmax], int n_lines, int n_columns,
 }
 int  auxString2Int(char *c,int *n)
 {    int j=0; *n=0;  while(('0'<=c[j])&&(c[j]<='9')) *n = 10*(*n)+c[j++]-'0';
-     if(j) while(c[j]==' ') j++; return j;
+     if(j) while(c[j]==' ') j++;
+     return j;
 }
 void CWSZerror(char *c)
 {    printf("Format error %s in Read_CWS_Zinfo\n",c);exit(0);
@@ -81,7 +83,9 @@ int  Read_CWS_Zinfo(FILE *inFILE,CWS *CW)		      /* return !EOF */
      for(n=0;n<999;n++)
      {	c[n]=fgetc(inFILE); if(feof(inFILE)) return 0; if(c[n]=='\n') break;
      }  if(n==999) {puts("Out of space in Read_CWS_Zinfo");exit(0);}
-     while(c[i]==b)i++; if((c[i]=='=')&&(c[i+1]=='d'))i+=2; while(c[i]==b)i++; 
+     while(c[i]==b)i++;
+     if((c[i]=='=')&&(c[i+1]=='d'))i+=2;
+     while(c[i]==b)i++; 
      /*	printf("Read_CWS_Zinfo n=%d -> ",n);
 	{int I; for(I=0;I<n;I++)printf("%c",c[I]);puts("");} */
      while(i<n)
@@ -133,14 +137,16 @@ int  ReadCwsPp(CWS *_CW, PolyPointList *_P, int codim, int index)
        puts("  or `#lines #columns' (= `PolyDim #Points' or `#Points PolyDim'):");}
      for(i=0;i<AMBI_Dmax*(AMBI_Dmax+1);i++)
      { char c;
-       while(' '==(c=fgetc(inFILE ))); ungetc(c,inFILE);    /* read blanks */
+       while(' '==(c=fgetc(inFILE )));
+       ungetc(c,inFILE);    /* read blanks */
        if(IsNextDigit()) fscanf(inFILE,"%d",&IN[i]); else break;
      }
      if(i==0) { if(!InputOK){puts("-h gives you help\n"); exit(0);}
 	else return 0; } InputOK++;
      if(i==1) { puts("Error in INPUT: need at least 2 numbers!"); exit(0);}
      if(i==2) 					      /* READ PolyPointList */
-     {	int tr=0;    while('\n'!=fgetc(inFILE));      /* read to end of line */
+     {	int tr=0;
+       while('\n'!=fgetc(inFILE));      /* read to end of line */
        if(IN[0]==IN[1]){ 
 	 puts("The number of points must be larger than the dimension!");
 	 exit(0);}
@@ -160,7 +166,8 @@ int  ReadCwsPp(CWS *_CW, PolyPointList *_P, int codim, int index)
 	  {   int X; fscanf(inFILE,"%d",&X); _P->x[i][j]=X;	}
 	/* Finish_Poly_Points(_P); */
 	while(fgetc(inFILE )-'\n') if(feof(inFILE)) return 0;/* read to EOL */
-     	if(FilterFlag) inFILE=NULL; return 1;
+     	if(FilterFlag) inFILE=NULL;
+	return 1;
      }  /* End of reading PolyPointList */
      assert(i!=3);
      S=IN[i-1]; 
@@ -206,7 +213,8 @@ MAP: for(i=0;i<_CW->nw;i++)			/* check consistency of CWS */
      if(!Read_CWS_Zinfo(inFILE,_CW))			   /* read Z to EOL */
      {	if(!InputOK) puts("-h gives you help\n"); return 0;}
      Make_CWS_Points(_CW, _P);
-     if(FilterFlag) inFILE=NULL; return 1;
+     if(FilterFlag) inFILE=NULL;
+     return 1;
 }
 
 int  Read_CWS_PP(CWS *_CW, PolyPointList *_P){
@@ -225,14 +233,16 @@ int  Read_PP(PolyPointList *_P)
      };
      for(i=0;i<AMBI_Dmax*(AMBI_Dmax+1);i++)
      { char c;
-       while(' '==(c=fgetc(inFILE ))); ungetc(c,inFILE);    /* read blanks */
+       while(' '==(c=fgetc(inFILE )));
+       ungetc(c,inFILE);    /* read blanks */
        if(IsNextDigit()) fscanf(inFILE,"%d",&IN[i]); else break;
      }
      if(i==0) { if(!InputOK){puts("-h gives you help\n"); exit(0);}
 	else return 0; } InputOK++;
      if(i==1) { puts("Error in INPUT: need at least 2 numbers!"); exit(0);}
      if(i==2) 					      /* READ PolyPointList */
-     {	int tr=0;    while('\n'!=fgetc(inFILE));      /* read to end of line */
+     {	int tr=0;
+       while('\n'!=fgetc(inFILE));      /* read to end of line */
        if(IN[0]==IN[1]){ 
 	 puts("The number of points must be larger than the dimension!");
 	 exit(0);}
@@ -252,10 +262,12 @@ int  Read_PP(PolyPointList *_P)
 	  {   int X; fscanf(inFILE,"%d",&X); _P->x[i][j]=X;	}
 	/* Finish_Poly_Points(_P); */
 	while(fgetc(inFILE )-'\n') if(feof(inFILE)) return 0;/* read to EOL */
-     	if(FilterFlag) inFILE=NULL; return 1;
+     	if(FilterFlag) inFILE=NULL;
+	return 1;
      }
      if(i>2){puts("Error: expected input format is matrix of polytope points!");exit(0);}
-     if(FilterFlag) inFILE=NULL; return 1;
+     if(FilterFlag) inFILE=NULL;
+     return 1;
 }
 
 int  Read_CWS(CWS *_CW, PolyPointList *_P)
@@ -271,7 +283,8 @@ int  Read_CWS(CWS *_CW, PolyPointList *_P)
      };
      for(i=0;i<AMBI_Dmax*(AMBI_Dmax+1);i++)
      { char c;
-       while(' '==(c=fgetc(inFILE ))); ungetc(c,inFILE);    /* read blanks */
+       while(' '==(c=fgetc(inFILE )));
+       ungetc(c,inFILE);    /* read blanks */
        if(IsNextDigit()) fscanf(inFILE,"%d",&IN[i]); else break;
      }
      if(i==0) { if(!InputOK){puts("-h gives you help\n"); exit(0);}
@@ -320,7 +333,8 @@ MAP: for(i=0;i<_CW->nw;i++)			/* check consistency of CWS */
      if(!Read_CWS_Zinfo(inFILE,_CW))			   /* read Z to EOL */
      {	if(!InputOK) puts("-h gives you help\n"); return 0;}
      Make_CWS_Points(_CW, _P);				   /* now make POLY */
-     if(FilterFlag) inFILE=NULL; return 1;
+     if(FilterFlag) inFILE=NULL;
+     return 1;
 }
 
 void Print_CWH(CWS *_W, BaHo *_BH){
@@ -372,14 +386,16 @@ void Orig_Solve_Next_WEq(Long *NW, CWLatticeBasis *_B)
 	if(NW[i]) {p[P]=i; W[P++]=NW[i];}		/* non-zero weights */
      }
      if(P<2) puts("need two non-zero weights in  >>Solve_Next_WEq<<");
-     for(i=0;i<p[0];i++) _B->x[i][i]=1; while((++i)<p[1]) _B->x[i-1][i]=1;
+     for(i=0;i<p[0];i++) _B->x[i][i]=1;
+     while((++i)<p[1]) _B->x[i-1][i]=1;
      G=Fgcd(W[0],W[1]); if(W[0]/G<0) G=-G;
      _B->x[i-1][p[0]]=-W[1]/G; _B->x[i-1][p[1]]=W[0]/G;
      j=2; while(++i<_B->N)
      {	if(NW[i])
 	{   int k; Long *X=_B->x[i-1], K[AMBI_Dmax], g=REgcd(W, &j, K); 
 	    G=Fgcd(g,NW[i]); if(g/G<0) G=-G; X[i]= g/G; g=W[j]/G;
-	    for(k=0;k<j;k++) X[p[k]]=-K[k]*g; j++;
+	    for(k=0;k<j;k++) X[p[k]]=-K[k]*g;
+	    j++;
 	}
 	else _B->x[i-1][i]=1;
      }
@@ -395,10 +411,12 @@ void Solve_Next_WEq(Long *NW, CWLatticeBasis *_B)
 	if(NW[i]) {p[P]=i; X[P]=GLZ[P]; W[P++]=NW[i];}	/* non-zero weights */
      }	if(P>1) W_to_GLZ(W,&P,X);		/* P>1, compute GLZ */
      else {/* printf("P=%d W[0]=%d for W_to_GLZ\n",P,W[0]);exit(0);*/assert(P);
-	for(i=0;i<p[0];i++)_B->x[i][i]=1; while((++i)<_B->N)_B->x[i-1][i]=1;
+	for(i=0;i<p[0];i++)_B->x[i][i]=1;
+	while((++i)<_B->N)_B->x[i-1][i]=1;
 	return; }
      for(i=1;i<P;i++) if(X[i][i]<0) for(j=0;j<=i;j++) X[i][j] *= -1;
-     for(i=0;i<p[0];i++) _B->x[i][i]=1; while((++i)<p[1]) _B->x[i-1][i]=1;
+     for(i=0;i<p[0];i++) _B->x[i][i]=1;
+     while((++i)<p[1]) _B->x[i-1][i]=1;
      _B->x[i-1][p[0]]=X[1][0]; _B->x[i-1][p[1]]=X[1][1]; j=2;
      while(++i<_B->N)
      {	if(NW[i])
@@ -463,7 +481,8 @@ void Reduce_PPL_2_Sublat(PolyPointList *P,int *nm,Long *M,Long G[][POLY_Dmax])
 	{   X[i]=0; for(j=0;j<P->n;j++) X[i]+=G[i][j]*P->x[N][j];
 	}   for(i=0;i<*nm;i++) if(X[i]%M[i]) break; if(i<*nm) continue;
 	for(i=0;i<*nm;i++) P->x[n][i]=X[i]/M[i]; 
-	for(i=*nm;i<P->n;i++) P->x[n][i]=X[i]; n++;
+	for(i=*nm;i<P->n;i++) P->x[n][i]=X[i];
+	n++;
      }	P->np=n; /* Print_PPL(P,"");printf("nm=%d\n",*nm); */
 }
 Long PD_Floor(Long N,Long D)	/*  assuming PosDenom  D>0:  F <= N/D < F+1  */
@@ -719,3 +738,78 @@ void CWS_to_PermCWS(CWS *Cin, CWS *C, int *pi)
 	for(i=0;i<N;i++) C->z[j][i]=Cin->z[j][pi[i]];}
 }
 #endif
+
+/*  ==========        For WS for 5d-polytopes, Sep 2017         ==========  */
+int int_ld(Long w){int i=-1; while (w) {w /= 2; i++;} return i;}
+
+void Initialize_C5S(C5stats *_C5S, int n){
+  int k;
+  _C5S->n_nonIP = 0;
+  _C5S->n_IP_nonRef = 0;
+  _C5S->n_ref = 0;
+  _C5S->nr_max_mp = 0;
+  _C5S->nr_max_mv =  0;
+  _C5S->nr_max_nv = 0;
+  _C5S->nr_max_w = 0;
+  for (k=0; k<MAXLD; k++) {_C5S->n_w[k] = 0; _C5S->nr_n_w[k] = 0;}
+  _C5S->max_mp = 0;
+  _C5S->max_mv = 0;
+  _C5S->max_np = 0;
+  _C5S->max_nv = 0;
+  _C5S->max_h22 = 0;
+  _C5S->max_w = 0;
+  for (k=1; k<n-1; k++) _C5S->max_h1[k] = 0;
+  for (k=0; k<=n; k++) _C5S->max_nf[k] = 0;
+  _C5S->max_chi = -100000000;
+  _C5S->min_chi = 100000000; 
+}
+
+void Update_C5S(BaHo *_BH, int *nf, Long *W, C5stats *_C5S){
+  if (_BH->np) { // reflexive case
+    int i, chi = 48+6*(_BH->h1[1]-_BH->h1[2]+_BH->h1[3]), ld = int_ld(W[5]);
+    assert(0<=ld); assert(ld<MAXLD);
+    if (_BH->mp > _C5S->max_mp) _C5S->max_mp = _BH->mp;
+    if (_BH->mv > _C5S->max_mv) _C5S->max_mv = _BH->mv;
+    if (_BH->np > _C5S->max_np) _C5S->max_np = _BH->np;
+    if (_BH->nv > _C5S->max_nv) _C5S->max_nv = _BH->nv;
+    if (_BH->h22 > _C5S->max_h22) _C5S->max_h22 = _BH->h22;
+    for (i=1; i<_BH->n-1; i++)
+      if (_BH->h1[i] > _C5S->max_h1[i]) _C5S->max_h1[i] = _BH->h1[i];
+    for (i=0; i<=_BH->n; i++)
+      if (nf[i] > _C5S->max_nf[i]) _C5S->max_nf[i] = nf[i];
+    if (chi > _C5S->max_chi) _C5S->max_chi = chi;
+    if (chi < _C5S->min_chi) _C5S->min_chi = chi;
+    _C5S->n_ref++;
+    _C5S->n_w[ld]++;
+    if(W[5] > _C5S->max_w) _C5S->max_w = W[5];}
+  else { // IP but non-reflexive case
+    if (_BH->mp > _C5S->nr_max_mp) _C5S->nr_max_mp = _BH->mp;
+    if (_BH->mv > _C5S->nr_max_mv)  _C5S->nr_max_mv = _BH->mv;
+    if (_BH->nv > _C5S->nr_max_nv) _C5S->nr_max_nv = _BH->nv;
+    _C5S->n_IP_nonRef++;
+    _C5S->nr_n_w[int_ld(W[5])]++;
+    if(W[5] > _C5S->nr_max_w) _C5S->nr_max_w = W[5];}
+}
+    
+void Print_C5S(C5stats *_C5S){
+  int i;
+  printf("non-IP: #=%ld\n", _C5S->n_nonIP);
+  printf("IP, non-reflexive: #=%ld, max_mp=%d, max_mv=%d, max_nv=%d, max_w=%ld\n",
+	 _C5S->n_IP_nonRef, _C5S->nr_max_mp, _C5S->nr_max_mv, _C5S->nr_max_nv,
+	 _C5S->nr_max_w);
+  printf("  #(w5) of given ld: ");
+  for (i=0; i<MAXLD; i++) printf(" %d:%ld", i, _C5S->nr_n_w[i]);
+  puts("");
+  printf("reflexive: #=%ld, max_mp=%d, max_mv=%d, max_np=%d, max_nv=%d, max_w=%ld\n",
+	 _C5S->n_ref, _C5S->max_mp, _C5S->max_mv, _C5S->max_np, _C5S->max_nv,
+	 _C5S->max_w);
+  printf("  #(w5) of given ld: ");
+  for (i=0; i<MAXLD; i++) printf(" %d:%ld", i, _C5S->n_w[i]);
+  puts("");
+  printf("  max #(faces): %d %d %d %d %d\n", _C5S->max_nf[0], _C5S->max_nf[1],
+	 _C5S->max_nf[2], _C5S->max_nf[3], _C5S->max_nf[4]);
+  printf("  h11<=%d, h12<=%d, h13<=%d, h22<=%d, %d<=chi<=%d\n",
+	 _C5S->max_h1[1], _C5S->max_h1[2], _C5S->max_h1[3],
+	 _C5S->max_h22, _C5S->min_chi, _C5S->max_chi);
+}
+
