@@ -118,12 +118,18 @@ int  Init_Multiloop(int *N, int *I, int *j, int *J);
 int  Multiloop(int *N,int *I,int *j,int *J);
 
 /*  do {;} while(Choose(n,k,C));       <--> forall 0 <= C[0]<...<C[k-1] < n */
-int Init_Choose(int n,int k,int *C){int i;
-  long X=1; assert(k>0); assert(k<=n); for(i=0;i<k;i++){
-    C[i]=i; X*=(n-i); X/=(i+1);} return X;}	      /* return (n choose k) */
+int Init_Choose(int n,int k,int *C){
+  int i;  long X=1; assert(k>0); assert(k<=n);
+  for(i=0;i<k;i++){
+    C[i]=i; X*=(n-i); X/=(i+1);}
+  return X;}	      /* return (n choose k) */
 int Choose(int n, int k, int *C){int x;
-  for(x=0;x<k-1;x++) if(C[x]<C[x+1]-1) {int i;	// hole => ++ and below -> min
-    for(i=0;i<x;i++) C[i]=i; C[x]++; return 1;} assert(x==k-1);
+  for(x=0;x<k-1;x++) if(C[x]<C[x+1]-1) {
+      int i;	// hole => ++ and below -> min
+      for(i=0;i<x;i++) C[i]=i;
+      C[x]++;
+      return 1;}
+  assert(x==k-1);
   if(C[x]<n-1){int i;for(i=0;i<x;i++)C[i]=i;C[x]++;return 1;} else return 0;}
 
 /*  ==============    I N T E R S E C T I O N   R I N G	  ================   */
@@ -158,7 +164,8 @@ void DivClassBasis(FILE *SF,PolyPointList *P,int v,char *D,char *B){
 
       if(EXCEPT_DIV_CLASS_BASE) for(c=0;c<d;c++) CC[c]=C[c];
       else for(c=0;c<d;c++) CC[c]=v-1-C[c];	/* eliminate D_max first */
-      for(c=0;c<d;c++) X[c]=P->x[CC[c]]; sv=SimplexVolume(X,P->n);
+      for(c=0;c<d;c++) X[c]=P->x[CC[c]];
+      sv=SimplexVolume(X,P->n);
       if(sv==cdiv){int x=0; fprintf(SF,"\nideal DCbase=");
       	Inci64 I=makeN(CC[0]); for(c=1;c<d;c++) I+=makeN(CC[c]);
         for(c=0;c<v;c++) if(!getN(c,I)) {if(x)fprintf(SF,",");
@@ -183,7 +190,8 @@ void OLD_LinRelLatticeBasis(FILE *SF,PolyPointList *P,int v,char *D,char *B){
     sv=SimplexVolume(X,P->n); cdiv=NNgcd(cdiv,sv);
     if(sv==1) {x=0; fprintf(SF,"\nideal DCbase=");
       for(y=0;y<v;y++) if(!getN(y,I)) {		      /* integral basis B[] */
-        if(x) fprintf(SF,","); fprintf(SF,"%s%d-%s%d",B,++x,D,y+1);} 
+        if(x) fprintf(SF,",");
+	fprintf(SF,"%s%d-%s%d",B,++x,D,y+1);} 
       assert(x==v-4); fprintf(SF,";\n"); return;}}
 
   if(cdiv>1){printf("Fundamental group = Z%d\n",(int)cdiv);fflush(0);
@@ -193,7 +201,8 @@ void OLD_LinRelLatticeBasis(FILE *SF,PolyPointList *P,int v,char *D,char *B){
     sv=SimplexVolume(X,P->n); 
     if(sv==cdiv) {x=0; fprintf(SF,"\nideal DCbase=");
       for(y=0;y<v;y++) if(!getN(y,I)) {		      /* integral basis B[] */
-        if(x)fprintf(SF,",");fprintf(SF,"%s%d-%s%d",B,++x,D,y+1);} /* OFFSET */
+        if(x)fprintf(SF,",");
+	fprintf(SF,"%s%d-%s%d",B,++x,D,y+1);} /* OFFSET */
       assert(x==v-4); fprintf(SF,";\n"); return;}}
    }
   puts("IMPROVE CODE: no Vol=1 simplex in LinRelLatticeBasis!!!");exit(0);
@@ -219,14 +228,18 @@ void CatFile(char *fn){char CAT[30+L_tmpnam];strcpy(CAT,"cat ");
 
 void MoriGen(Matrix T,Long *V){int i; Matrix G; Init_Matrix(&G,T.d,T.d); 
   assert(T.d==T.v+1); assert(T.v==Make_G_for_GxMT_UT(T,G));
-  for(i=0;i<T.d;i++) V[i]=G.x[T.v][i]; Free_Matrix(&G);}
+  for(i=0;i<T.d;i++) V[i]=G.x[T.v][i];
+  Free_Matrix(&G);}
 
 void Print_CMatrix(Matrix M, char *s){int i,j;
-  fprintf(outFILE,"%d %d CV %s\n",M.d,M.v,s);for(i=0;i<M.d;i++){for(j=0;j<M.v;
-    j++)fprintf(outFILE,"%2d%s",(int) M.x[j][i],(j+1==M.v) ? "\n" : " ");}}
+  fprintf(outFILE,"%d %d CV %s\n",M.d,M.v,s);
+  for(i=0;i<M.d;i++){
+    for(j=0;j<M.v;j++)
+      fprintf(outFILE,"%2d%s",(int) M.x[j][i],(j+1==M.v) ? "\n" : " ");}}
 
-void Print_VNL(VertexNumList *V){int i; for(i=0;i<V->nv;i++)
-  fprintf(outFILE,"%d ",V->v[i]); fprintf(outFILE,"#=%d\n",V->nv);}
+void Print_VNL(VertexNumList *V){int i;
+  for(i=0;i<V->nv;i++) fprintf(outFILE,"%d ",V->v[i]);
+  fprintf(outFILE,"#=%d\n",V->nv);}
 
 int  Vdiff_LmR(Long *L,Long *R,int d){ 
   while(d--){Long D=L[d]-R[d]; if(D) return (D>0) ? 1 : -1;} return 0;}
@@ -278,7 +291,8 @@ assert(Inci64_abs(Ia)==2); assert(b<d);
     if(Z[b]>0) for(a=0;a<=d;a++) R.x[r][V.v[a]]=Z[a]; 
     else for(a=0;a<=d;a++) R.x[r][V.v[a]]=-Z[a];
 //for(a=0;a<p;a++)printf("%ld ",R.x[r][a]);printf("=Z::R[%d]\n",r);fflush(0);
-    for(b=0;b<r;b++) if(!Vdiff_LmR(R.x[r],R.x[b],p)) break; if(b==r) r++; }
+    for(b=0;b<r;b++) if(!Vdiff_LmR(R.x[r],R.x[b],p)) break;
+    if(b==r) r++; }
   R.v=UT->np=ngen=r; r=Make_G_for_GxMT_UT(R,G); 	// base change -> UT
   if(r!=p-d) { Matrix GR; R.v=ngen; Print_LMatrix(R,"R");
     Print_LMatrix(G,"GLZ"); Init_Matrix(&GR,R.v,p);
@@ -290,7 +304,8 @@ assert(Inci64_abs(Ia)==2); assert(b<d);
   if(r>POLY_Dmax){fprintf(outFILE,"need POLY_Dmax>=%d\n",UT->n);exit(0);}
   for(i=0;i<ngen;i++) for(j=0;j<r;j++) UT->x[i][j]=VxV(G.x[j],R.x[i],p);
   for(i=0;i<ngen;i++) for(j=r;j<p;j++) assert(0==VxV(G.x[j],R.x[i],p));
-  for(i=0;i<UT->n;i++)UT->x[UT->np][i]=0; UT->np++; Find_Equations(UT,&V,E);
+  for(i=0;i<UT->n;i++) UT->x[UT->np][i]=0;
+  UT->np++; Find_Equations(UT,&V,E);
   np=UT->np-1; nv=V.nv-1; Sort_VL(&V); 
 
   Free_Matrix(&VT); Free_Matrix(&R); Free_Matrix(&G); free(E); free(UT); 
@@ -322,7 +337,8 @@ assert(Inci64_abs(Ia)==2); assert(b<d);
     if(Z[b]>0) for(a=0;a<=d;a++) R.x[r][V.v[a]]=Z[a]; 
     else for(a=0;a<=d;a++) R.x[r][V.v[a]]=-Z[a];
 //for(a=0;a<p;a++)printf("%ld ",R.x[r][a]);printf("=Z::R[%d]\n",r);fflush(0);
-    for(b=0;b<r;b++) if(!Vdiff_LmR(R.x[r],R.x[b],p)) break; if(b==r) r++; }
+    for(b=0;b<r;b++) if(!Vdiff_LmR(R.x[r],R.x[b],p)) break;
+    if(b==r) r++; }
   R.v=UT->np=ngen=r; r=Make_G_for_GxMT_UT(R,G); 	// base change -> UT
   if(r!=p-d) { Matrix GR; R.v=ngen;Print_LMatrix(R,"R");
     Print_LMatrix(G,"GLZ"); Init_Matrix(&GR,R.v,p);
@@ -334,7 +350,8 @@ assert(Inci64_abs(Ia)==2); assert(b<d);
   if(r>POLY_Dmax){fprintf(outFILE,"need POLY_Dmax>=%d\n",UT->n);exit(0);}
   for(i=0;i<ngen;i++) for(j=0;j<r;j++) UT->x[i][j]=VxV(G.x[j],R.x[i],p);
   for(i=0;i<ngen;i++) for(j=r;j<p;j++) assert(0==VxV(G.x[j],R.x[i],p));
-  for(i=0;i<UT->n;i++)UT->x[UT->np][i]=0; UT->np++; Find_Equations(UT,&V,E);
+  for(i=0;i<UT->n;i++) UT->x[UT->np][i]=0;
+  UT->np++; Find_Equations(UT,&V,E);
   np=UT->np-1; nv=V.nv-1; Sort_VL(&V); 
   if(np!=V.v[nv]){IDerr();puts("MORI CONE not strictly convex:");
     Print_Inci64_list(nI,I,p);puts("... non-convex triangulation?\n");exit(0);}
@@ -388,7 +405,8 @@ void Triang_from_SR(triang *TR,triang *SR){	/* consistency check ... */
   int i=1, p=TR->v=SR->v, j=p/2, d=TR->d=SR->d, s=SR->n, m=0, k, l, r;   
   Inci64 *S=SR->I,*T=TR->I, *A,*M,*N; long long binco=TR->v; /* Bino.Coeff */
   assert(p<=64); if(j>d)j=d+1; while(i<j){binco*=(p-i);binco/=++i;}
-  if(binco++>2999)binco=2999; A = (Inci64*) malloc(2*binco*sizeof(Inci64));
+  if(binco++>2999) binco=2999;
+  A = (Inci64*) malloc(2*binco*sizeof(Inci64));
   assert(A!=NULL); M=A; N=&A[binco];
   for(i=1;i<p;i++)for(j=0;j<i;j++){M[m]= makeN(i)+makeN(j);	
     for(k=0;k<s;k++) if(Inci64_LE(S[k],M[m])) break;  /* no edge of triangle */
@@ -403,7 +421,9 @@ void Triang_from_SR(triang *TR,triang *SR){	/* consistency check ... */
 void StanleyReisner(triang *SR,triang *T){ /* pre-allocate and compute SR(T) */
   Inci64 *S=SR->I,*I=T->I,*A,*M,*N,U=1; long long binco=T->v; /* Binom.Coeff */
   int i=1, p=T->v, j=p/2, d=T->d,nI=T->n, s=0, m=0, k, l, r; 	 assert(p<=64);
-  if(j>d)j=d+1; while(i<j){binco*=(p-i);binco/=++i;}if(binco++>2999)binco=2999;
+  if(j>d) j=d+1;
+  while(i<j) {binco*=(p-i); binco/=++i;}
+  if(binco++>2999) binco=2999;
 
   A = (Inci64*) malloc(2*binco*sizeof(Inci64));assert(A!=NULL);M=A;N=&A[binco];
   for(i=1;i<p;i++)for(j=0;j<i;j++){M[m]=(U<<i)+(U<<j);		/* OFFSET=0 */
@@ -423,8 +443,11 @@ void StanleyReisner(triang *SR,triang *T){ /* pre-allocate and compute SR(T) */
     {Inci64 sumT=0,sumC=0;for(i=0;i<T->n;i++){sumT+=TeST.I[i];sumS+>T->I[i];}
       if(sumT!=sumC) ok=0;}
 #else
-    {for(i=0;i<T->n;i++) {int sum=0; for(j=0;j<T->n;j++) 
-      if(TeST.I[i]==T->I[j]) sum++; if(sum!=1) break;} if(i<T->n) ok=0;}
+    {for(i=0;i<T->n;i++) {
+	int sum=0;
+	for(j=0;j<T->n;j++) if(TeST.I[i]==T->I[j]) sum++;
+	if(sum!=1) break;}
+      if(i<T->n) ok=0;}
 #endif
     if(ok)free(A); else {PRNtriang(T,"Triangulation");PRNtriang(SR,"SR-ideal");
       PRNtriang(&TeST,"Tri(SR) ... test failed !!!"); assert(0);}
@@ -483,8 +506,11 @@ void GaleTransform(Matrix A,Matrix *B){
  */
 
 int AcuteAngle(Long *L,Long *R){return L[0]*R[0]+L[1]*R[1]>0;} // R.L>0
-int ConeAngle(Long *L,Long *R){Long X=L[1]*R[0]-L[0]*R[1]; // 0->0, (0,pi) ->+1
-  if(X>0)return 1;if(X<0)return -1;return(AcuteAngle(L,R)>0)?0:-1;}// [pi,)->-1
+int ConeAngle(Long *L,Long *R){
+  Long X=L[1]*R[0]-L[0]*R[1]; // 0->0, (0,pi) ->+1
+  if(X>0)return 1;
+  if(X<0)return -1;
+  return(AcuteAngle(L,R)>0)?0:-1;}// [pi,)->-1
 
 #define BZangle(a,b)	(ConeAngle(B.x[Z[a]],B.x[Z[b]]))	// Gale-points
 /*
@@ -508,12 +534,16 @@ Inci64 FindPolyCircuits(PolyPointList *P,int p,Inci64 F,int f){
  */
 #define	SameRayBZ(a,b)		(SameRay(B.x[Z[a]],B.x[Z[b]],B.d))
 
-int  SameRay(Long *X,Long *Y,int d){int x=0,y=000; while(d--)
-  if(x) {if(y*X[d]!=x*Y[d]) return 0;} else
-  if(X[d]) {if(Y[d]){Long g=Fgcd(X[d],Y[d]); x=X[d]/g; y=Y[d]/g;}
-    else return 0;} else {if(Y[d]) return 0;}
+int  SameRay(Long *X,Long *Y,int d){
+  int x=0,y=000;
+  while(d--)
+    if(x) {if(y*X[d]!=x*Y[d]) return 0;}
+    else if(X[d]) {
+      if(Y[d]){Long g=Fgcd(X[d],Y[d]); x=X[d]/g; y=Y[d]/g;}
+      else return 0;}
+    else {if(Y[d]) return 0;}
   if(x) return (x*y>0); else {puts("ZeroVectors in SameRay (forbidden)");
-  assert(x); return 000;}}
+    assert(x); return 000;}}
 
 Long XYZproduct(Long *X,Long *Y,Long *Z){return Z[2]*(X[0]*Y[1]-X[1]*Y[0])
   +Z[0]*(X[1]*Y[2]-X[2]*Y[1])+Z[1]*(X[2]*Y[0]-X[0]*Y[2]);}
@@ -536,8 +566,11 @@ int InterSectE(Long *X,Long *Y,Long *U,Long *V){
     uvy=XYZproduct(U,V,Y); if((0<=xyu*xyv)||(0<=uvx*uvy)) return 0; 
     if(xyu*uvx<0) return 1; else return -1;}
 
-void MakeVecPrim(Long *X){Long g=1;if(X[0]*X[1])g=Fgcd(X[0],X[1]);
-  if(X[2])g=Fgcd(g,X[2]); if(g<0)g=-g; if(g>1){X[0]/=g;X[1]/=g;X[2]/=g;}}
+void MakeVecPrim(Long *X){
+  Long g=1;if(X[0]*X[1])g=Fgcd(X[0],X[1]);
+  if(X[2]) g=Fgcd(g,X[2]);
+  if(g<0) g=-g;
+  if(g>1) {X[0]/=g;X[1]/=g; X[2]/=g;}}
 
 void IntersectEdges(Long *X,Long *Y,Long *U,Long *V,Long *Q){
   Long XY[3],UV[3]; CROSSproduct(X,Y,XY); MakeVecPrim(XY);
@@ -566,8 +599,11 @@ void Print_MaxTrian(Inci64 C, Inci64 *CT[ANtri], int nmt, int *nt,int p)
 int Triang1dSFan(PolyPointList *P,int p,Inci64 I,Inci64 *X,Inci64 *CT[ANtri],
   int *nmt, int *nt)			// P,p,F[c],X,CT[nmf],&nmt[nmf],nt[nmf]
 { int d=P->n,i,j,k=0,tnt=0, F[POLY_Dmax+1]; Inci64 CI=0; Matrix A,B; 
-  Init_Matrix(&A,d+1,d); for(i=0;i<p;i++) if(getN(i,I)){
-    for(j=0;j<d;j++) A.x[k][j]=P->x[i][j]; F[k++]=i;} assert(k==d+1); 
+  Init_Matrix(&A,d+1,d);
+  for(i=0;i<p;i++) if(getN(i,I)){
+      for(j=0;j<d;j++) A.x[k][j]=P->x[i][j];
+      F[k++]=i;}
+  assert(k==d+1); 
   GaleTransform(A,&B); i=j=*nmt=0; 
   for(k=0;k<=d;k++) if(*B.x[k]) {CI|=makeN(F[k]); if(*B.x[k]>0) i++; else j++;}
 #if (TRACE_TRIANGULATION)
@@ -579,10 +615,14 @@ int Triang1dSFan(PolyPointList *P,int p,Inci64 I,Inci64 *X,Inci64 *CT[ANtri],
 	printf("=C -> ");
 	Print_CMatrix(B,"Gale"); 
 #endif
-  if(i>1){CT[*nmt]=X; nt[*nmt]=0; for(k=0;k<=d;k++) 
-    if(*B.x[k]>0) CT[*nmt][nt[*nmt]++]=CI-makeN(F[k]); tnt+=i; (*nmt)++;}
-  if(j>1){CT[*nmt]=X+i; nt[*nmt]=0; for(k=0;k<=d;k++) 
-    if(*B.x[k]<0) CT[*nmt][nt[*nmt]++]=CI-makeN(F[k]); tnt+=j; (*nmt)++;}
+  if(i>1){
+    CT[*nmt]=X; nt[*nmt]=0;
+    for(k=0;k<=d;k++) if(*B.x[k]>0) CT[*nmt][nt[*nmt]++]=CI-makeN(F[k]);
+    tnt+=i; (*nmt)++;}
+  if(j>1){
+    CT[*nmt]=X+i; nt[*nmt]=0;
+    for(k=0;k<=d;k++) if(*B.x[k]<0) CT[*nmt][nt[*nmt]++]=CI-makeN(F[k]);
+    tnt+=j; (*nmt)++;}
 #if (TRACE_TRIANGULATION)
     Print_MaxTrian(CI,CT,*nmt,nt,p); //printf("i=%d j=%d nmt=%d\n",i,j,*nmt);
 #endif
@@ -683,8 +723,11 @@ int Triang3dSFan(PolyPointList *P,int p,Inci64 FI,Inci64 *X,Inci64 *CT[ANtri],
       ,BZR(T[2]),Q))) if(0<=(c=XYZproduct(BZR(T[2]),BZR(T[0]),Q)))
     {assert(a*b*c>0); return 1;} return 0;}		 // END of DECLARATIONS */
 
-  Init_Matrix(&A,Inci64_abs(FI),d);for(i=0;i<=p;i++)if(getN(i,FI)){	// GALE
-    for(j=0;j<d;j++) A.x[f][j]=P->x[i][j]; F[f++]=i;} 	GaleTransform(A,&B);
+  Init_Matrix(&A,Inci64_abs(FI),d);
+  for(i=0;i<=p;i++) if(getN(i,FI)){	// GALE
+    for(j=0;j<d;j++) A.x[f][j]=P->x[i][j];
+    F[f++]=i;}
+  GaleTransform(A,&B);
   for(i=0;i<f;i++) if(B.x[i][0]||B.x[i][1]||B.x[i][2]) 	C+=makeN(F[Z[z++]=i]);
 
   for(i=0;i<z;i++) { for(j=0;j<r;j++) if(SameRayBZ(i,R[j][0]))	   // Make RAYS
@@ -718,8 +761,11 @@ int Triang3dSFan(PolyPointList *P,int p,Inci64 FI,Inci64 *X,Inci64 *CT[ANtri],
     if(eb){Eli[en][0]=a;Eli[en][1]=c; Einc[en++]=makeN(a)+makeN(c);} 
     if(ec){Eli[en][0]=a;Eli[en][1]=b; Einc[en++]=makeN(a)+makeN(b);} tn++;}
 
-  for(a=0;a<en;a++){for(b=0;b<r;b++) if(!Inci64_LE(makeN(b),Einc[a])) // remove
-    if(XYZcone(BZR(Eli[a][0]),BZR(b),BZR(Eli[a][1]))>0)break;if(b<r){ // SPLIT
+  for(a=0;a<en;a++){
+    for(b=0;b<r;b++)
+      if(!Inci64_LE(makeN(b),Einc[a])) // remove
+	if(XYZcone(BZR(Eli[a][0]),BZR(b),BZR(Eli[a][1]))>0)break;
+    if(b<r){ // SPLIT
 #if (TRACE_TRIANGULATION)                                         // EDGES
       printf("Ray %d divides edge[%d]=%d%d\n",b,a,Eli[a][0],Eli[a][1]);
 #endif
@@ -727,9 +773,10 @@ int Triang3dSFan(PolyPointList *P,int p,Inci64 FI,Inci64 *X,Inci64 *CT[ANtri],
 
 
 
-  for(l=0;l<en;l++) ien[l]=0; for(l=1;l<en;l++) 	// INTERSECTing EDGES
-  for(k=0;k<l;k++) if(0<InterSectE(BZRE(k,0),BZRE(k,1),BZRE(l,0),
-    BZRE(l,1))) {IEli[k][ien[k]++]=l;IEli[l][ien[l]++]=k;}
+  for(l=0;l<en;l++) ien[l]=0;
+  for(l=1;l<en;l++) 	// INTERSECTing EDGES
+    for(k=0;k<l;k++) if(0<InterSectE(BZRE(k,0),BZRE(k,1),BZRE(l,0),BZRE(l,1)))
+		       {IEli[k][ien[k]++]=l;IEli[l][ien[l]++]=k;}
 
   for(i=0;i<en;i++) if(ien[i]){if(iem<ien[i])iem=ien[i]; ies+=ien[i]; nQuad++;}
 
@@ -763,7 +810,8 @@ int Triang3dSFan(PolyPointList *P,int p,Inci64 FI,Inci64 *X,Inci64 *CT[ANtri],
   if(iem>1){int OE[8*VERT_Nmax][2],noe=0,y,q=0; // orient.edges, y = #Rays+#Q's
     Long *Y[VERT_Nmax],YY[VERT_Nmax][3];
     int nse=0;for(i=0;i<en;i++)nse+=1+ien[i]; // printf("SubdivEdge=%d\n",nse);
-    for(y=0;y<r;y++) Y[y]=BZR(y); Y[y]=YY[0];	assert(nse<=VERT_Nmax);
+    for(y=0;y<r;y++) Y[y]=BZR(y);
+    Y[y]=YY[0];	assert(nse<=VERT_Nmax);
 
 #ifdef	CANNOT_HANDLE_CONINCIDENT_INTERSECTION_POINTS	// o.k. for iem==2 ???
 {   Inci64 Qinc[VERT_Nmax]; 	
@@ -887,7 +935,8 @@ for(l++;l<noe+f;l++) assert(-1==XYZcone(Y[OE[l][0]],Y[k],Y[OE[l][1]]));
       IEI[nie++]=Einc[j]; assert(Einc[j]==makeN(Eli[j][0])+makeN(Eli[j][1]));
       IntersectEdges(BZRE(i,0),BZRE(i,1),BZRE(j,0),BZRE(j,1),Q);
       for(a=0;a<2;a++)for(b=0;b<2;b++){Long *rA=BZRE(i,a),*rB=BZRE(j,b);
-        for(c=0;c<3;c++) CR[ncr][c]=Q[c]+rA[c]+rB[c]; ncr++;}
+        for(c=0;c<3;c++) CR[ncr][c]=Q[c]+rA[c]+rB[c];
+	ncr++;}
       }	assert(nie==2*ies);	chi=r-en+3*ies; // QUAD DONE, NOW MIN.TRIANG:
     for(i=0;i<tn;i++){a=Tli[i][0]; b=Tli[i][1]; c=Tli[i][2];
       for(k=0;k<r;k++) if(k!=a) if(k!=b) if(k!=c)	// if (k not in (abc))
@@ -956,12 +1005,20 @@ int Induce_Facet_Tri(Inci64 *T,int N,Inci64 f,Inci64 C, Inci64 *iT,int p,int d){
 
 int Compatible_Tri(Inci64 CA,Inci64 CB,int a,Inci64 *A,int b,Inci64 *B,int p){
   Inci64 I=CA&CB, IA[VERT_Nmax], IB[VERT_Nmax]; int i, ia=1, ib=1;
-  *IA=(*A)&I; for(i=1;i<a;i++) {int j; Inci64 X=A[i]&I; for(j=0;j<ia;j++) 
-    if(Inci64_LE(X,IA[j])) break; if(j==ia) {for(j=0;j<ia;j++) 
-      if(Inci64_LE(IA[j],X)) IA[j--]=IA[--ia]; IA[ia++]=X;}}
-  *IB=(*B)&I; for(i=1;i<b;i++) {int j; Inci64 X=B[i]&I; for(j=0;j<ib;j++) 
-    if(Inci64_LE(X,IB[j])) break; if(j==ib) {for(j=0;j<ib;j++) 
-      if(Inci64_LE(IB[j],X)) IB[j--]=IB[--ib]; IB[ib++]=X;}}
+  *IA=(*A)&I; for(i=1;i<a;i++) {
+    int j; Inci64 X=A[i]&I;
+    for(j=0;j<ia;j++) if(Inci64_LE(X,IA[j])) break;
+    if(j==ia) {
+      for(j=0;j<ia;j++) 
+      if(Inci64_LE(IA[j],X)) IA[j--]=IA[--ia];
+      IA[ia++]=X;}}
+  *IB=(*B)&I;
+  for(i=1;i<b;i++) {
+    int j; Inci64 X=B[i]&I;
+    for(j=0;j<ib;j++) if(Inci64_LE(X,IB[j])) break;
+    if(j==ib) {
+      for(j=0;j<ib;j++) if(Inci64_LE(IB[j],X)) IB[j--]=IB[--ib];
+      IB[ib++]=X;}}
 #if	TRACE_TRIANGULATION
   puts("Compatibility of induced triangulations:");
   prnI(p,CA);printf(" & "); prnI(p,CB); printf(" = "); prnI(p,CA&CB); puts("");
@@ -973,8 +1030,10 @@ int Compatible_Tri(Inci64 CA,Inci64 CB,int a,Inci64 *A,int b,Inci64 *B,int p){
 	for(i=0;i<b;i++){prnI(p,B[i]),printf(" ");}	puts("");
 #endif
   if(ia!=ib) return 0; else for(i=0;i<ia;i++) if(IA[i]!=IB[i]) break;
-  if(i==ia) return 1; else for(i=0;i<ia;i++) {int sum=0, j;
-    for(j=0;j<ib;j++) if(IA[i]==IB[j]) sum++; if(sum!=1) return 0;} 
+  if(i==ia) return 1; else for(i=0;i<ia;i++) {
+      int sum=0, j;
+      for(j=0;j<ib;j++) if(IA[i]==IB[j]) sum++;
+      if(sum!=1) return 0;} 
   p=0;
   return 1;}
 
@@ -1354,7 +1413,10 @@ void HyperSurfDivisorsQ(PolyPointList *_P, VertexNumList *V, EqList *E,
 //    while(Multiloop(N,L,&j,&J)); assert(c==0);}
 
   if(_Flag->M) TriList_to_MoriList(_P, F, _Flag);
-  else {
+  else if (_Flag->g||_Flag->m||_Flag->b||_Flag->i
+	   ||_Flag->c||_Flag->t||_Flag->d||_Flag->H)
+    Subdivide(_P,V->nv,I,cp,T,&t, _Flag ,F);
+  if (0) {  /* seems to be left-over rubbish  */
     PolyPointList *DP = (PolyPointList *) malloc(sizeof(PolyPointList));
     EqList *DE = (EqList *) malloc(sizeof(EqList));
     PairMat PM,DPM; 
@@ -1409,21 +1471,22 @@ void FE(char *c){puts("Input format error in ");puts(c);exit(0);}
 /*needed from Read_Tri*/
 void Read_EOL(){
 	char c;
-	while('\n'!=(c=fgetc(inFILE)))
-		if(feof(inFILE))FE("EOF");
+	while('\n'!=(c=fgetc(inFILE)))	if(feof(inFILE))FE("EOF");
 }
 
 int  ReadInt()
 {    int n; char c=fgetc(inFILE); if(!IsDigit(c)&&(c!='-')) FE("ReadInt");
      ungetc(c,inFILE); fscanf(inFILE,"%d",&n);
-     while(' '==(c=fgetc(inFILE))); ungetc(c,inFILE); return n;
+     while(' '==(c=fgetc(inFILE)));
+     ungetc(c,inFILE); return n;
 }
 
 /*needed from Read_Tri*/
 Inci64 Read_INCI(int p){    
   Inci64 X=Inci64_1(); /* dirty: starts with the 1 required by the old format */
   char c; 
-  while(' '==(c=fgetc(inFILE))); ungetc(c,inFILE);
+  while(' '==(c=fgetc(inFILE)));
+  ungetc(c,inFILE);
   while(IsDigit(c=fgetc(inFILE))) {assert(c<'2'); X=Inci64_PN(X,'1'-c); p--;}
   if(p) {
     IFerr(); 
@@ -1499,14 +1562,17 @@ void Print_Mori_Old(PolyPointList *P,int nI, Inci64 *I){
   PolyPointList *UT = (PolyPointList *) malloc(sizeof(PolyPointList));
   Matrix R,VT,G; EqList *E = (EqList*)malloc(sizeof(EqList));
   assert(E!=NULL); assert(UT!=NULL);
-  for(i=1;i<nI;i++)for(j=0;j<i;j++) ngen+=(Inci64_abs(Inci64_AND(I[i],I[j]))==d);
+  for(i=1;i<nI;i++) for(j=0;j<i;j++)
+		      ngen+=(Inci64_abs(Inci64_AND(I[i],I[j]))==d);
   Init_Matrix(&VT,d,d+1);Init_Matrix(&R,ngen,p);Init_Matrix(&G,p,p); ng0=ngen;
   for(i=1;i<nI;i++) for(j=0;j<i;j++) if(Inci64_abs(Inci64_AND(I[i],I[j]))==d) {
     int a,b,x; INCI_2_VNL(I[j],&V,p); assert(V.nv==d+1);
-    for(k=0;k<=d;k++) pli[k]=V.v[k]; INCI_2_VNL(I[i],&V,p);
+    for(k=0;k<=d;k++) pli[k]=V.v[k];
+    INCI_2_VNL(I[i],&V,p);
     if((V.v[0]==0)&&(pli[0]==0)){k=1; while(pli[k]==V.v[k]) k++; assert(k<=d);}
     else{for(a=0;a<=d;a++)printf("%d ",pli[a]);puts("=Ii");/*adj.simplex pair*/
-      for(a=0;a<=d;a++)printf("%d ",V.v[a]);    puts("=Ij ... error");
+      for(a=0;a<=d;a++) printf("%d ",V.v[a]);
+      puts("=Ij ... error");
       Print_INCI_list(nI,I,p); exit(0);}
     if(pli[k]>V.v[k]) pli[0]=V.v[x=k]; 	      /* pli[x-1] < pli[0] < pli[x] */
     else{if(k<d)while(pli[k+1]==V.v[k])if((++k)==d)break; pli[0]=V.v[k];x=k+1;}
@@ -1520,7 +1586,8 @@ void Print_Mori_Old(PolyPointList *P,int nI, Inci64 *I){
     if(Z[0]>0) for(a=0;a<=d;a++) R.x[r][pli[a]]=Z[a];
     else for(a=0;a<=d;a++) R.x[r][pli[a]]=-Z[a];
 //for(a=0;a<p;a++)printf("%d ",R.x[r][a]);printf("=Z::R[%d]\n",r);
-    for(b=0;b<r;b++) if(!Vdiff_LmR(R.x[r],R.x[b],p)) break; if(b==r) r++; }
+    for(b=0;b<r;b++) if(!Vdiff_LmR(R.x[r],R.x[b],p)) break;
+    if(b==r) r++; }
   R.v=UT->np=ngen=r; r=Make_G_for_GxMT_UT(R,G);
   if(r!=P->np-P->n-1) { Matrix GR; R.v=ngen;Print_LMatrix(R,"R");
     Print_LMatrix(G,"GLZ"); Init_Matrix(&GR,R.v,p);
@@ -1532,7 +1599,8 @@ void Print_Mori_Old(PolyPointList *P,int nI, Inci64 *I){
   if(r>POLY_Dmax){fprintf(outFILE,"need POLY_Dmax>=%d\n",UT->n);exit(0);}
   for(i=0;i<ngen;i++) for(j=0;j<r;j++) UT->x[i][j]=VxV(G.x[j],R.x[i],p);
   for(i=0;i<ngen;i++) for(j=r;j<p;j++) assert(0==VxV(G.x[j],R.x[i],p));
-  for(i=0;i<UT->n;i++)UT->x[UT->np][i]=0; UT->np++; Find_Equations(UT,&V,E);
+  for(i=0;i<UT->n;i++)UT->x[UT->np][i]=0;
+  UT->np++; Find_Equations(UT,&V,E);
 
   np=UT->np-1; nv=V.nv-1; Sort_VL(&V);
   if(np!=V.v[nv]) {IDerr(); puts("Suspected INCI data error:");
@@ -1543,8 +1611,10 @@ void Print_Mori_Old(PolyPointList *P,int nI, Inci64 *I){
       Eval_Eq_on_V(&E->e[i],UT->x[V.v[j]],r));}/* compute Eq(0)-INCIs for Vs */
   if(e0>VERT_Nmax){fprintf(outFILE,"need VERT_Nmax >= %d\n",e0);exit(0);}
 //printf("p=%d nm=%d\n",p,nm);
-  for(i=0;i<nv;i++){for(j=0;j<nv;j++)
-    if(Inci64_LE(IE[i],IE[j])&&!Inci64_EQ(IE[i],IE[j])) break;if(j==nv) m[nm++]=i;}
+  for(i=0;i<nv;i++){
+    for(j=0;j<nv;j++)
+      if(Inci64_LE(IE[i],IE[j])&&!Inci64_EQ(IE[i],IE[j])) break;
+    if(j==nv) m[nm++]=i;}
   assert(nm>=r); fprintf(outFILE,
     "%d MORI GENERATORS / dim(cone)=%d"
 //    ": rays=%d (%d)  #eq=%d (%d)  #v=%d (%d)"
@@ -1555,7 +1625,8 @@ void Print_Mori_Old(PolyPointList *P,int nI, Inci64 *I){
 //printf("p=%d nm=%d\n",p,nm);fflush(0);
   for(i=0;i<nm;i++){ int n=V.v[m[i]]; Long s=0;
     for(j=1;j<p;j++)s+=R.x[n][j]; // fprintf(outFILE,"%3ld ",-s);
-    for(j=1;j<p;j++)fprintf(outFILE," %2ld",R.x[n][j]); fputs("   I:",outFILE);
+    for(j=1;j<p;j++) fprintf(outFILE," %2ld",R.x[n][j]);
+    fputs("   I:",outFILE);
     Write_INCI(IE[m[i]],e0); fputs("\n",outFILE);fflush(0);}
   Free_Matrix(&VT); Free_Matrix(&R); Free_Matrix(&G); free(E); free(UT); 
 }
@@ -1615,17 +1686,19 @@ void TriList_to_MoriList(PolyPointList * _P, FibW *F, MORI_Flags * _Flag){
   PolyPointList *_POF = malloc(sizeof(PolyPointList)); /* _P in Old Format */
 
   //	fprintf(outFILE, "DIAGNOSTICS: pre Read &I=%d , I=%d , nI=%d , nIA=%d \n", &I, I, nI, nIA); // diagnostics
+
+  if (_Flag->FilterFlag) inFILE = stdin;
   
   _POF->n = _P->n;
   _POF->np = _P->np;
   for (j=0;j<_P->np-1;j++) for (i=0;i<_P->n;i++) _POF->x[j+1][i] = _P->x[j][i];
   for (i=0;i<_P->n;i++) _POF->x[0][i] = 0;
 
-  printf("`#triangulations': \n");
+  if (!_Flag->FilterFlag)   printf("`#triangulations': \n");
   Ntri=ReadInt();
   Read_EOL();
   //Print_PPL(_POF, "_POF:");
-  fprintf(outFILE, "%d triangulations:\n", Ntri);
+  if (!_Flag->FilterFlag)   fprintf(outFILE, "%d triangulations:\n", Ntri);
   fflush(0);
   
   for(n=0; n<Ntri; n++) {
@@ -1719,4 +1792,5 @@ void TriList_to_MoriList(PolyPointList * _P, FibW *F, MORI_Flags * _Flag){
     free(IOF);
   }
   assert(I!=NULL); free(I);
+  if (_Flag->FilterFlag) inFILE = NULL;
 }
