@@ -75,7 +75,8 @@ void Read_Aux_File(NF_List *);
 void Init_FInfoList(FInfoList *FI)
 {    int i, j;
      FI->nNF= FI->nSM= FI->nNM= FI->NB=0; FI->nVmax= FI->NUCmax= FI->nV=0; 
-     for(i=0;i<=VERT_Nmax;i++) FI->nNUC[i]=0; FI->NFli=NULL;
+     for(i=0;i<=VERT_Nmax;i++) FI->nNUC[i]=0;
+     FI->NFli=NULL;
      for(i=0;i<=VERT_Nmax;i++) for(j=0;j<NUC_Nmax;j++) FI->NFnum[i][j]=0;
 }
 
@@ -85,7 +86,7 @@ void Init_New_List(NF_List *S)
      S->PE  = (PEnt  *) malloc( (SAVE_INC+SL_Nmax) * sizeof(PEnt)  );
      S->PPE = (PPEnt *) malloc( ADD_LIST_LENGTH * sizeof(PPEnt) );
      S->SLp = (int   *) malloc( SL_Nmax * sizeof(int)   );
-     S->NewNF = (unsigned char *) malloc( S->ANB * sizeof(char) );
+     S->NewNF = (unsigned char *) malloc( S->ANB * sizeof(char) ); S->NC = 0;
      assert((S->PE!=NULL)&&(S->PPE!=NULL)&&(S->SLp!=NULL)&&(S->NewNF!=NULL));
 #ifdef  __DECC
         /* printf("NULL=%p S->PE=%p S->NewNF=%p\n",NULL,S->PE,S->NewNF); */
@@ -95,7 +96,7 @@ void Init_New_List(NF_List *S)
 NF_List *AuxNFLptr=NULL;		/* dirty trick for Xmin Xmax Xdif */
 void Init_NF_List(NF_List *L)
 {    
-     L->TIME= L->SAVE= time(NULL); printf(ctime(&L->TIME)); L->CLOCK= clock();
+     L->TIME= L->SAVE= time(NULL); fputs(ctime(&L->TIME),stdout); L->CLOCK= clock();
      L->IP_Time = L->NF_Time = 0;  L->d = L->nNF = L->nIP = L->nSLNF = 0;
      
      Init_FInfoList(&L->In);	if(*L->iname) Read_In_File(L);	
@@ -206,7 +207,8 @@ void Read_Honest_Poly(FILE *F,FInfoList *FI,NF_List *L)
      printf("%lld+%dsl %lldm+%ds %lldb",L->NP-L->nSLP,L->nSLP, 
 			FI->nNF-FI->nSM-FI->nNM,FI->nSM, FI->NB+L->NewNB); 
 	if(L->rd) printf(" rd=%d",L->rd);
-     if(FI->NFli != NULL) printf("WARNing: NFli != NULL"); fflush(stdout);
+     if(FI->NFli != NULL) printf("WARNing: NFli != NULL");
+     fflush(stdout);
      FI->NFli = (unsigned char *) malloc( FI->NB * sizeof(char) );
      if(FI->NFli==NULL) {puts("Aux.NFli allocation failed");exit(0);}
      for(v=L->d+1;v<=FI->nVmax;v++) if(FI->nNUC[v]) 
@@ -250,7 +252,8 @@ void Read_Aux_File(NF_List *L)
      int NCalloc=strlen(L->oname)+strlen(SAVE_FILE_EXT)+ (USE_TMP_DIR ? 6 : 1);
      char *auxfn = (char *) malloc(NCalloc);
      if(USE_TMP_DIR) {strcpy(auxfn,"/tmp/"); strcat(auxfn,L->oname);} 
-     else strcpy(auxfn,L->oname); 	     strcat(auxfn,SAVE_FILE_EXT);
+     else strcpy(auxfn,L->oname);
+     strcat(auxfn,SAVE_FILE_EXT);
      F=fopen(auxfn,"rb"); printf("Reading %s: ",auxfn); fflush(stdout);
      if(F==NULL) puts("No aux-file found!"); 
      else
@@ -349,10 +352,13 @@ void Write_Bin_File(FILE *F,NF_List *L)
      fflush(stdout);
      nVmax=max(L->Aux.nVmax,AI.nVmax); NUCmax=max(L->Aux.NUCmax,AI.NUCmax);
      for(i=L->d+1;i<=nVmax;i++)
-     {	int v_li=0; for(j=1;j<=NUCmax;j++)
-	if((NFnum[i][j]=L->Aux.NFnum[i][j]+AI.NFnum[i][j])) v_li++; li+=v_li;
-	if(v_li) fi++;
-     }	assert(L->rd <= MAX_REC_DEPTH);
+     { int v_li=0;
+       for(j=1;j<=NUCmax;j++)
+	 if((NFnum[i][j]=L->Aux.NFnum[i][j]+AI.NFnum[i][j])) v_li++;
+       li+=v_li;
+       if(v_li) fi++;
+     }
+     assert(L->rd <= MAX_REC_DEPTH);
      if(L->rd < 128) fputc(L->rd,F);
      else {fputc(128+(L->rd)/128,F); fputc((L->rd)%128,F);} 
      for(n=0;n<L->rd;n++) fputc(L->b[n],F); 
@@ -420,7 +426,8 @@ void Write_Aux_File(NF_List *S)
      char *tmpfn = auxfn;
 #endif
      if(USE_TMP_DIR) {strcpy(auxfn,"/tmp/"); strcat(auxfn,S->oname);} 
-     else strcpy(auxfn,S->oname);            strcat(auxfn,SAVE_FILE_EXT);
+     else strcpy(auxfn,S->oname);
+     strcat(auxfn,SAVE_FILE_EXT);
      F=fopen(tmpfn,"wb"); printf("Writing %s: ",auxfn); fflush(stdout); 
      if(F==NULL){puts("Cannot open!");exit(0);}
      Write_Bin_File(F,S); if(ferror(F)) {puts("File ERROR!!");exit(0);}
@@ -726,14 +733,16 @@ int  Add_NF_to_List(PolyPointList *_P, VertexNumList *_V, EqList *_E,
      int NewNF; 
 #ifdef INCREMENTAL_TIME
      long long cpuT=clock(), incT=cpuT - _L->CLOCK; 
-     if(incT>0) _L->IP_Time+=incT; _L->CLOCK=cpuT;
+     if(incT>0) _L->IP_Time+=incT;
+     _L->CLOCK=cpuT;
 #endif
      if((_E->ne)>_L->F) _L->F=_E->ne;		/* check vertex numbers */
      if((_V->nv)>_L->V) _L->V=_V->nv;
      if((_E->ne > VERT_Nmax)||(_V->nv > VERT_Nmax))
      {	printf("Increase VERT_Nmax:  f=%d v=%d\n",_E->ne,_V->nv);exit(0);
      }
-     if(_P->np>_L->Nmax) _L->Nmax=_P->np; if(_P->np<_L->Nmin) _L->Nmin=_P->np;
+     if(_P->np>_L->Nmax) _L->Nmax=_P->np;
+     if(_P->np<_L->Nmin) _L->Nmin=_P->np;
      _L->nNF++; if(_L->SL)_L->nSLNF++;  
 
      VF_2_ucNF(_P, _V, _E,  &NV, &nUC, UC); 
@@ -742,7 +751,8 @@ int  Add_NF_to_List(PolyPointList *_P, VertexNumList *_V, EqList *_E,
 
 #ifdef INCREMENTAL_TIME
      cpuT=clock(), incT=cpuT - _L->CLOCK; 
-     if(incT>0) _L->NF_Time+=incT; _L->CLOCK=cpuT;
+     if(incT>0) _L->NF_Time+=incT;
+     _L->CLOCK=cpuT;
 #endif
      return NewNF;
 }
@@ -826,19 +836,22 @@ void BaseGetInt(int *base, int *x, UXLong *X)  /* x = X mod b, X /= b */
 }
 int  BminOff(Long V[POLY_Dmax][VERT_Nmax], int *d, int *v, int *off, int *bmin)
 {    int i, j, moff=0, vmax=0;
-     for(i=0;i<*d;i++)for(j=i;j<*v;j++)
-     {	Long x=V[i][j]; if(moff>x) moff=x; if(vmax<x) vmax=x;
+     for(i=0;i<*d;i++) for(j=i;j<*v;j++)
+     {	Long x=V[i][j]; if(moff>x) moff=x;
+       if(vmax<x) vmax=x;
      }
      *off=-moff; *bmin=*off+vmax+1;
 #ifdef	USE_UNIT_ENCODE
-     for(i=0;i<*d;i++)for(j=i;j<*d;j++) if(V[i][j]!=(i==j))return 0; return 1;
+     for(i=0;i<*d;i++) for(j=i;j<*d;j++) if(V[i][j]!=(i==j)) return 0;
+     return 1;
 #else
      return 0;
 #endif
 }
 void AuxBase2nUC(int *base, int *nx, int *nuc)      /* b^nx-2=x0+x1*USM+... */
 {    int i, m=*base-1; UXLong X; X.n=0; /* m=X->n-1 =>	  ... + xm*USM^xm   */
-     for(i=0;i<*nx-1;i++) BasePutInt(base,&m,&X); m--; BasePutInt(base,&m,&X);
+     for(i=0;i<*nx-1;i++) BasePutInt(base,&m,&X);
+     m--; BasePutInt(base,&m,&X);
      i=UNIT_OFF; m=i-1;	BasePutInt(&i,&m,&X); *nuc=2*X.n-(X.x[X.n-1]<256);
 }
 void AuxNextGoodBase(int *v,int *nx,Base_List *BL)  /* nx= v*d -d*(d-1)/2 */
@@ -864,7 +877,7 @@ void Bmin2BaseUCn(int *d, int *v, int *bmin,  int *base, int *nuc)
      Base_List *BL; Init_BaseList(&BL,d); n=&(BL->v[*v]); i=*n-1;
 
      if(*bmin<=BL->base[*v][i])
-     {	while(*bmin <= (BL->base[*v][i-1])) if(--i==0) break;
+     { while(i > 0 && *bmin <= (BL->base[*v][i-1])) --i;
      }
      else
      {	do AuxNextGoodBase(v,&nx,BL); while(*bmin > (BL->base[*v][++i]));
@@ -875,7 +888,7 @@ void NUCtoBase(int *d, int *v, int *nuc, int *Base)
 {    int i, *n, nx = NX(*d,*v);
      Base_List *BL; Init_BaseList(&BL,d); n=&(BL->v[*v]); i=*n-1;
      if(*nuc<=BL->nuc[*v][i])
-     {	while(*nuc <= (BL->nuc[*v][i-1])) if(--i==0) break;
+     { while(i > 0 && *nuc <= (BL->nuc[*v][i-1])) --i;
      }
      else
      {	do AuxNextGoodBase(v,&nx,BL); while(*nuc > (BL->nuc[*v][++i]));
@@ -899,7 +912,7 @@ void UNIT_Bmin2BaseUCn(int *d, int *v, int *bmin,  int *base, int *nuc)
 {    int i, *n, nx = UNIT_NX(*d,*v);
      Base_List *BL; UNIT_Init_BaseList(&BL,d); n=&(BL->v[*v]); i=*n-1;
      if(*bmin<=BL->base[*v][i])
-     {	while(*bmin <= (BL->base[*v][i-1])) if(--i==0) break;
+     { while(i > 0 && *bmin <= (BL->base[*v][i-1])) --i;
      }
      else
      {	do AuxNextGoodBase(v,&nx,BL); while(*bmin > (BL->base[*v][++i]));
@@ -910,7 +923,7 @@ void UNIT_NUCtoBase(int *d, int *v, int *nuc, int *Base)
 {    int i, *n, nx = UNIT_NX(*d,*v);
      Base_List *BL; UNIT_Init_BaseList(&BL,d); n=&(BL->v[*v]); i=*n-1;
      if(*nuc<=BL->nuc[*v][i])
-     {	while(*nuc <= (BL->nuc[*v][i-1])) if(--i==0) break;
+     { while(i > 0 && *nuc <= (BL->nuc[*v][i-1])) --i;
      }
      else
      {	do AuxNextGoodBase(v,&nx,BL); while(*nuc > (BL->nuc[*v][++i]));
@@ -926,7 +939,8 @@ void AuxVnf2ucNF(Long nf[POLY_Dmax][VERT_Nmax], int *d, int *v,
      for(i=0;i<*d;i++) for(j = (one) ? *d : i ;j<*v;j++)
      {	int x=nf[i][j]+(*off); BasePutInt(base,&x,&X);
      }	
-     if(one) BasePutInt(base,off,&X);	     i=UNIT_OFF; BasePutInt(&i,ms,&X);
+     if(one) BasePutInt(base,off,&X);
+     i=UNIT_OFF; BasePutInt(&i,ms,&X);
      for(i=X.n;(2*i)<(*nuc);i++) X.x[i]=0;
      for(i=0;i<*nuc;i++)if(i%2) UC[i]=X.x[i/2] /UCM; else UC[i]=X.x[i/2] %UCM;
 }
@@ -934,7 +948,8 @@ void UCnf2vNF(int *d, int *v, int *nuc, unsigned char *uc,  	      /* IN */
 	      Long NF[POLY_Dmax][VERT_Nmax], int *MS)		     /* OUT */
 {    int i, j, off=0, base, one;
      UXLong X; X.n=*nuc/2; if(*nuc % 2) X.x[X.n++]=uc[*nuc-1];
-     for(i=0;i<*nuc/2;i++) X.x[i]=uc[2*i]+UCM*uc[2*i+1]; 	i=UNIT_OFF; 
+     for(i=0;i<*nuc/2;i++) X.x[i]=uc[2*i]+UCM*uc[2*i+1];
+     i=UNIT_OFF; 
      BaseGetInt(&i,MS,&X); one = (*MS > 3);
 #ifdef	USE_UNIT_ENCODE
      if(one) {UNIT_NUCtoBase(d,v,nuc,&base); BaseGetInt(&base,&off,&X);} else
@@ -967,7 +982,8 @@ void VF_2_ucNF(PolyPointList *P, VertexNumList *V, EqList *E,	      /* IN */
      unsigned char auxUC[POLY_Dmax*VERT_Nmax];
      int MS=0, vb,vo,vnuc,vbmin, fb,fo,fnuc,fbmin, vone=0,fone=0,MSone;
 #ifndef	SORT_NUC_FIRST
-     if(V->nv<E->ne) MS=1; if(V->nv>E->ne) MS=2;
+     if(V->nv<E->ne) MS=1;
+     if(V->nv>E->ne) MS=2;
 #endif					/* else: priority to sorting by nuc */
      assert(Init_rVM_VPM(P,V,E,&P->n,&V->nv,&E->ne,VM,VPM));/* make ref VPM */
      if(MS <2)
@@ -1036,10 +1052,12 @@ void VF_2_ucNF(PolyPointList *P, VertexNumList *V, EqList *E,	      /* IN */
      {	Long tNF[POLY_Dmax][VERT_Nmax]; int tMS, i, j, *d=&P->n, err=0;
 	static int pn, Err; 
 	pn++;				UCnf2vNF(d, NV, nUC, UC,   tNF, &tMS);
-	if(MS<2) for(i=0;i<*d;i++)
-	for(j=i;j<*NV;j++) err+=(tNF[i][j]!=V_NF[i][j]); if(err) err*=1000;
-	if(MS-1) for(i=0;i<*d;i++)for(j=i;j<*NV;j++)
-	    err+=(tNF[i][j]!=F_NF[i][j]);	if(err) Err=1;
+	if(MS<2) for(i=0;i<*d;i++) for(j=i;j<*NV;j++)
+				     err+=(tNF[i][j]!=V_NF[i][j]);
+	if(err) err*=1000;
+	if(MS-1) for(i=0;i<*d;i++) for(j=i;j<*NV;j++)
+				     err+=(tNF[i][j]!=F_NF[i][j]);
+	if(err) Err=1;
 	if(Err) 
 	{   int base;
 #ifdef	USE_UNIT_ENCODE
@@ -1098,7 +1116,8 @@ void AuxPut_hNF(FILE *F,int *v,int *nu,unsigned char *Huc,FInfoList *Io,
 	default: puts("inconsistent MS flags in AuxPut_hNF"); exit(0);}
 
 	if(Sms) {if(Sms<3) (*slNM)--;} else (*slSM)--;	/* remove SL-entry */
-	for(i=pos--;i<*slNF;i++) SLp[i-1]=SLp[i]; (*slNF)--; (*slNB)-= *nu+2;
+	for(i=pos--;i<*slNF;i++) SLp[i-1]=SLp[i];
+	(*slNF)--; (*slNB)-= *nu+2;
      }
 }
 /*	Alloc & read SL; go thru pi / pa; write SL + statistics
@@ -1136,7 +1155,7 @@ void Add_Polya_2_Polyi(char *polyi,char *polya,char *polyo)
      {	AuxGet_vn_uc(FI,&vI,&nuI,ucI); uc = &ucSL[ 2 + (SLp[slNF++]=slNB) ];
 	while(a<AslNF)
 	{   if(!(AmI=vA-vI)) if(!(AmI=nuA-nuI))
-	    AmI=RIGHTminusLEFT(ucI,ucA,&nuI);
+			       AmI=RIGHTminusLEFT(ucI,ucA,&nuI);
 	    if(AmI<0)						   /* put A */
 	    {	uc[-2]=vA; uc[-1]=nuA; for(j=0;j<nuA;j++)uc[j]=ucA[j];
 		slNB+=2+nuA; if((ms=(*uc%4))) {if(ms<3) slNM++;} else slSM++;
@@ -1149,7 +1168,8 @@ void Add_Polya_2_Polyi(char *polyi,char *polya,char *polyo)
 	{   uc[-2]=vI; uc[-1]=nuI; for(j=0;j<nuI;j++) uc[j]=ucI[j];
 	    if((*ucI%4)!=(*ucA%4)) *uc = 3+4*(*uc/4);
 	    if((ms=(*uc%4))) {if(ms<3) slNM++;} else slSM++;
-	    if((++a)<AslNF) AuxGet_vn_uc(FA,&vA,&nuA,ucA);	tnb+=2+nuI;
+	    if((++a)<AslNF) AuxGet_vn_uc(FA,&vA,&nuA,ucA);
+	    tnb+=2+nuI;
 	}
 	else							   /* put I */
 	{   uc[-2]=vI; uc[-1]=nuI; for(j=0;j<nuI;j++) uc[j]=ucI[j];
@@ -1307,7 +1327,8 @@ void ANF_2_ucNF(PolyPointList *P, VertexNumList *V, EqList *E,	      /* IN */
 	static int pn; 
 	pn++;		UCnf_2_ANF(d, NV, nUC, UC,   tNF, &tMS);
 	for(i=0;i<*d;i++) for(j=0;j<*NV;j++) 
-	    err+=(tNF[i][j]!=V_NF[i][j]); if(err) err*=1000;
+	    err+=(tNF[i][j]!=V_NF[i][j]);
+	if(err) err*=1000;
 	if(err) 
 	{   int base;
 #ifdef	USE_UNIT_ENCODE
@@ -1330,14 +1351,16 @@ int  Add_ANF_to_List(PolyPointList *_P, VertexNumList *_V, EqList *_E,
 {    unsigned char UC[NB_MAX]; int nUC, NV, NewNF; 
 #ifdef INCREMENTAL_TIME
      long long cpuT=clock(), incT=cpuT - _L->CLOCK; 
-     if(incT>0) _L->IP_Time+=incT; _L->CLOCK=cpuT;
+     if(incT>0) _L->IP_Time+=incT;
+     _L->CLOCK=cpuT;
 #endif
      if((_E->ne)>_L->F) _L->F=_E->ne;           /* check vertex numbers */
      if((_V->nv)>_L->V) _L->V=_V->nv;
      if((_E->ne > VERT_Nmax)||(_V->nv > VERT_Nmax))
      {  printf("Increase VERT_Nmax:  f=%d v=%d\n",_E->ne,_V->nv);exit(0);
      }
-     if(_P->np>_L->Nmax) _L->Nmax=_P->np; if(_P->np<_L->Nmin) _L->Nmin=_P->np;
+     if(_P->np>_L->Nmax) _L->Nmax=_P->np;
+     if(_P->np<_L->Nmin) _L->Nmin=_P->np;
      _L->nNF++; if(_L->SL)_L->nSLNF++;  
 
      ANF_2_ucNF(_P, _V, _E,  &NV, &nUC, UC); 
@@ -1346,7 +1369,8 @@ int  Add_ANF_to_List(PolyPointList *_P, VertexNumList *_V, EqList *_E,
 
 #ifdef INCREMENTAL_TIME
      cpuT=clock(), incT=cpuT - _L->CLOCK; 
-     if(incT>0) _L->NF_Time+=incT; _L->CLOCK=cpuT;
+     if(incT>0) _L->NF_Time+=incT;
+     _L->CLOCK=cpuT;
 #endif
      return NewNF;
 }
