@@ -260,7 +260,8 @@ void Add_Polya_2_DBi(char *dbi,char *polya,char *dbo)
      FILE *FI, *FA, *FO;  if(*polya==0) {puts("-pa file required"); exit(0);}
 	Init_FInfoList(&FIi); Init_FInfoList(&FIa);
      strcpy(Ifn,dbi); Ifx=&Ifn[strlen(dbi)]; strcpy(Ifx,".info");
-     if(*dbo==0)dbo=dbi; strcpy(Ofn,dbo); Ofx=&Ofn[strlen(dbo)];
+     if(*dbo==0)dbo=dbi;
+     strcpy(Ofn,dbo); Ofx=&Ofn[strlen(dbo)];
 
      if(NULL==(FI=fopen(Ifn,"r")))   {printf("Cannot open %s",Ifn);exit(0);}
      if(NULL==(FA=fopen(polya,"rb"))){printf("Cannot open %s",polya);exit(0);}
@@ -294,7 +295,7 @@ void Add_Polya_2_DBi(char *dbi,char *polya,char *dbo)
      {	AuxGet_vn_uc(FI,&vI,&nuI,ucI); uc = &ucSL[ 2 + (SLp[slNF++]=slNB) ];
 	while(s<AslNF)
 	{   if(!(AmI=vA-vI)) if(!(AmI=nuA-nuI))
-	    AmI=RIGHTminusLEFT(ucI,ucA,&nuI);
+			       AmI=RIGHTminusLEFT(ucI,ucA,&nuI);
 	    if(AmI<0)						   /* put A */
 	    {	uc[-2]=vA; uc[-1]=nuA; for(j=0;j<nuA;j++)uc[j]=ucA[j];
 		slNB+=2+nuA; if( (ms=(*uc%4)) ) {if(ms<3) slNM++;} else slSM++;
@@ -307,7 +308,8 @@ void Add_Polya_2_DBi(char *dbi,char *polya,char *dbo)
 	{   uc[-2]=vI; uc[-1]=nuI; for(j=0;j<nuI;j++) uc[j]=ucI[j];
 	    if((*ucI%4)!=(*ucA%4)) *uc = 3+4*(*uc/4);
 	    if( (ms=(*uc%4)) ) {if(ms<3) slNM++;} else slSM++;
-	    if((++s)<AslNF) AuxGet_vn_uc(FA,&vA,&nuA,ucA);	tnb+=2+nuI;
+	    if((++s)<AslNF) AuxGet_vn_uc(FA,&vA,&nuA,ucA);
+	    tnb+=2+nuI;
 	}
 	else							   /* put I */
 	{   uc[-2]=vI; uc[-1]=nuI; for(j=0;j<nuI;j++) uc[j]=ucI[j];
@@ -480,7 +482,8 @@ void Check_NF_Order(char *polyi,char *dbi, int cF, PolyPointList *_P)/* 1=MM */
 
     	rd=fgetc(F); if(rd>127) rd=128*(rd-128)+fgetc(F);
 	assert(rd <= MAX_REC_DEPTH);    printf("rd=%d: ",rd);
-	for(i=0;i<rd;i++) printf(" %d",fgetc(F));if(rd) puts("");
+	for(i=0;i<rd;i++) printf(" %d",fgetc(F));
+	if(rd) puts("");
      
      	d=fgetc(F); L.nV=fgetc(F); L.nVmax=fgetc(F); L.NUCmax=fgetc(F);
      	list_num=fgetUI(F); 
@@ -491,7 +494,8 @@ void Check_NF_Order(char *polyi,char *dbi, int cF, PolyPointList *_P)/* 1=MM */
 
      	for(i=0;i<L.nV;i++)
      	{   v=fgetc(F); L.nNUC[v]=fgetc(F);   
-	    if(cF==2) printf("v%dn%d: ",v,L.nNUC[v]);fflush(stdout);
+	    if(cF==2) printf("v%dn%d: ",v,L.nNUC[v]);
+	    fflush(stdout);
             for(j=0;j<L.nNUC[v];j++)                  
             {   L.NFnum[v][nu=fgetc(F)]=fgetUI(F); /* read nuc and #NF(v,nu)*/
                 tNF+=L.NFnum[v][nu]; 
@@ -521,7 +525,8 @@ void Check_NF_Order(char *polyi,char *dbi, int cF, PolyPointList *_P)/* 1=MM */
 
      	for(i=0;i<L.nV;i++)
      	{   fscanf(F,"%d",&v); fscanf(F,"%d",&j); L.nNUC[v]=j;
-	    if(cF==2) printf("v%dn%d: ",v,L.nNUC[v]);fflush(stdout);
+	    if(cF==2) printf("v%dn%d: ",v,L.nNUC[v]);
+	    fflush(stdout);
             for(j=0;j<L.nNUC[v];j++) 
             {	fscanf(F,"%d",&nu); fscanf(F,"%d",&L.NFnum[v][nu]); tln++;
             	tNF+=L.NFnum[v][nu];  
@@ -554,7 +559,8 @@ void Check_NF_Order(char *polyi,char *dbi, int cF, PolyPointList *_P)/* 1=MM */
 	nu=fgetc(F); /* assert(nu<=L.NUCmax); */
 	AuxGet_uc(F,&nu,uc); assert(!ferror(F));
         if((*uc%4)==0)tSM++; 
-	else if((*uc%4)<3)tNM++; Test_ucNF(&d,&v,&nu,uc,_P); 
+	else if((*uc%4)<3)tNM++;
+	Test_ucNF(&d,&v,&nu,uc,_P); 
 	assert(Check_sl_order(&v,&nu,uc));
      }  if(sl_NB&&(*dbi))
      {  SLpos=FTELL(F); assert(sl_NB==SLpos); printf("NB o.k. ");
@@ -564,7 +570,8 @@ void Check_NF_Order(char *polyi,char *dbi, int cF, PolyPointList *_P)/* 1=MM */
      Print_Expect(&L);
     
      printf("\nv:"); if(*polyi) FSEEK(F,Hpos,SEEK_SET);	   /* check h-order */
-     if(cF<0) puts(""); for(v=d+1;v<=L.nVmax;v++)    /* if(cF) */ if(L.nNUC[v])
+     if(cF<0) puts("");
+     for(v=d+1;v<=L.nVmax;v++)    /* if(cF) */ if(L.nNUC[v])
      {  Along nbsum=0; if(cF>0){printf(" %d",v);fflush(stdout);}  if(*dbi) 
      	{   char vxt[5]; strcpy(vxt,".v"); vxt[2]=v/10+'0'; vxt[3]=v%10+'0'; 
 	    vxt[4]=0; strcpy(Ifx,vxt); fclose(F);
@@ -583,8 +590,8 @@ void Check_NF_Order(char *polyi,char *dbi, int cF, PolyPointList *_P)/* 1=MM */
         if(*dbi){Hpos=FTELL(F); assert(Hpos==nbsum);} assert(!ferror(F));
      }	
      printf("  sm=%d nm=%lld",tSM,tNM); printf("  order o.k.");
-     if((L.nSM!=(int)tSM)||(L.nNM!=tNM))
-				puts("    CheckSum ERROR!"); if(cF<0) return;
+     if((L.nSM!=(int)tSM)||(L.nNM!=tNM)) puts("    CheckSum ERROR!");
+     if(cF<0) return;
 
      printf("\nv:"); if(*polyi) FSEEK(F,Hpos,SEEK_SET);	      /* check h-NF */
      for(v=d+1;v<=L.nVmax;v++)        	if(L.nNUC[v])
@@ -693,7 +700,7 @@ void Reduce_Aux_File(char *polyi,char *polys,char *dbsub,char *polyo)
      {	AuxGet_vn_uc(FI,&vI,&nuI,ucI); uc = &ucSL[ 2 + (SLp[slNF++]=slNB) ];
 	while(s<SslNF)
 	{   if(!(SmI=vS-vI)) if(!(SmI=nuS-nuI))
-	    SmI=RIGHTminusLEFT(ucI,ucS,&nuI);
+			       SmI=RIGHTminusLEFT(ucI,ucS,&nuI);
 	    if(SmI<0)						  /* next S */
 	    {	if((++s)<SslNF) AuxGet_vn_uc(FS,&vS,&nuS,ucS);
 	    }
@@ -840,10 +847,14 @@ void Reduce_Aux_File(char *polyi,char *polys,char *dbsub,char *polyo)
 		{   int k, sms=uc[2]%4, hms=(*ucS)%4;
 		    switch(10*hms + sms){ 
 		    case 31: case 32: case 00: case 11: case 22: case 33: 
-		    	for(k=i+1;k<slNF;k++) SLp[k-1]=SLp[k]; slNB -= nu+2;
-			if(sms==0) --slSM; else if(sms<3) --slNM; --slNF;
-			if(i>=slNF) goto END_SL; uc = & (ucSL[SLp[i]]);
-			if((uc[0]!=v)||(uc[1]!=nu)) goto END_VN;	break;
+		    	for(k=i+1;k<slNF;k++) SLp[k-1]=SLp[k];
+			slNB -= nu+2;
+			if(sms==0) --slSM; else if(sms<3) --slNM;
+			--slNF;
+			if(i>=slNF) goto END_SL;
+			uc = & (ucSL[SLp[i]]);
+			if((uc[0]!=v)||(uc[1]!=nu)) goto END_VN;
+			break;
 		    case 12: case 21: 					break;
 		    case 13: case 23: ++slNM; uc[2]-=hms; 		break;
 		    default: puts("inconsistent MS flags in SL-H"); exit(0);}
@@ -932,7 +943,8 @@ void Bin2a(char *polyi, int max, PolyPointList *_P)
         "%dd  %dv<=%d n<=%d  %dnv  %lld %d %lld %lld  %d %d %d %d",
         d, L.nV, L.nVmax, L.NUCmax,list_num,
         L.nNF,L.nSM,L.nNM,L.NB,  sl_nNF, sl_SM, sl_NM, sl_NB);
-     if(max) printf("  r-max=%d",mc); puts("");
+     if(max) printf("  r-max=%d",mc);
+     puts("");
 }
 void DB_fromVF_toVT(DataBase *DB,int vf,int vt)
 {    int v,n; DB->nNF=0;
@@ -986,7 +998,8 @@ void Bin2aDBsl(char *dbi, int max, int vf, int vt, PolyPointList *_P)
         "%dd  %dv<=%d n<=%d  %dnv ... %d %d %d %d",  /* %d %d %d %lld */ 
         d, L.nV, L.nVmax, L.NUCmax,list_num,
         /* L.nNF,L.nSM,L.nNM,L.NB, */ sl_nNF, sl_SM, sl_NM, sl_NB);
-     if(max) printf("  r-max=%d",mc); puts("");
+     if(max) printf("  r-max=%d",mc);
+     puts("");
 }
 void Bin_2_ascii(char *polyi,char *dbin,int max,int vf,int vt,PolyPointList *P)
 {    if(*polyi)     Bin2a(polyi, max, P);
@@ -1407,7 +1420,7 @@ void Extract_from_Hodge_db(char *dbname, char *x_string, PolyPointList *_P){
 
   nnf_sum=0;
   if (H1&&H2) {HM_from=(H1<H2 ? H1 : H2); HM_to=HM_from;}
-  else if (H1||H2) {HM_from=0; HM_to=max(H1,H2);}
+  else if (H1||H2) {HM_to=max(H1,H2); HM_from=max(0,HM_to-Hod_Dif_max);}
 
   for (h12=HM_from; h12<=HM_to; h12++) {
 
@@ -1584,7 +1597,8 @@ int  Read_H_poly_from_DB(DataBase *DB,PolyPointList *P)
      int i,j, MS; Long NF[POLY_Dmax][VERT_Nmax]; VertexNumList V; EqList E; 
      if(0==ms3) { if(0==Read_H_ucNF_from_DB(DB,uc)) return 0;} else --uc[0];
      UCnf2vNF(&DB->d,&DB->v,&DB->nu,uc,NF,&MS); P->n=DB->d; P->np=DB->v;
-     for(i=0;i<P->np;i++)for(j=0;j<P->n;j++)P->x[i][j]=NF[j][i]; MS%=4;
+     for(i=0;i<P->np;i++) for(j=0;j<P->n;j++) P->x[i][j]=NF[j][i];
+     MS%=4;
      ms3=(MS==3); if(MS==2)
      {	assert(Ref_Check(P,&V,&E)); P->np=E.ne;
 	for(i=0;i<P->np;i++)for(j=0;j<P->n;j++) P->x[i][j]=E.e[i].a[j];
@@ -1630,22 +1644,31 @@ void Aux_Print_CoverPoly(int *I,int *d, int *N,Long *X[POLY_Dmax],
      {  fprintf(outFILE," /Z%ld:",M[i]);
         for(j=0;j<*N;j++) fprintf(outFILE," %ld",Z[i][j]);
      }	printf("  #%d\n",*x);
-     for(i=0;i<*d;i++){for(j=0;j<*N;j++){Long Xij=AuxGxP(G[i],X[j],d);
-	if(0!=(Xij % D[i])) err=1; printf("%ld ",Xij);} puts("");
+     for(i=0;i<*d;i++){
+       for(j=0;j<*N;j++){
+	 Long Xij=AuxGxP(G[i],X[j],d);
+	 if(0!=(Xij % D[i])) err=1;
+	 printf("%ld ",Xij);}
+       puts("");
      }
 #ifdef	TEST
 	if((dia==0)||err){
-	    int i,j;printf("D=");for(i=0;i<*d;i++)printf("%ld ",D[i]);
-	    printf("   index[%d]=%d\n",*x,*I);for(i=0;i<*d;i++)
-	    {printf("G=");for(j=0;j<*d;j++)printf("%2ld ",G[i][j]);
-	    printf("   G.P="); for(j=0;j<*N;j++)
-		printf("%2ld ",AuxGxP(G[i],X[j],d));puts("");} exit(0);}
+	  int i,j;printf("D=");for(i=0;i<*d;i++)printf("%ld ",D[i]);
+	  printf("   index[%d]=%d\n",*x,*I);
+	  for(i=0;i<*d;i++)	    {
+	    printf("G=");
+	    for(j=0;j<*d;j++) printf("%2ld ",G[i][j]);
+	    printf("   G.P=");
+	    for(j=0;j<*N;j++) printf("%2ld ",AuxGxP(G[i],X[j],d));
+	    puts("");}
+	  exit(0);}
 #endif
 }
 void Aux_Print_SLpoly(int *I,int *d, int *N,Long *X[POLY_Dmax],
 	Long G[][POLY_Dmax],Long *D,int *x)
 {    int i,j,dia=1, err=0; printf("%d %d    index=%d  D=%ld",*d,*N,*I,D[0]);
-     for(i=1;i<*d;i++) printf(" %ld",D[i]); printf("  #%d\n",*x);
+     for(i=1;i<*d;i++) printf(" %ld",D[i]);
+     printf("  #%d\n",*x);
      for(i=0;i<*d;i++)
      {	/* int z=1;*/ for(j=0;j<*N;j++)
 	{    Long Xij=AuxGxP(G[i],X[j],d);
@@ -1654,15 +1677,19 @@ void Aux_Print_SLpoly(int *I,int *d, int *N,Long *X[POLY_Dmax],
         if(dia==0)if(i==(*d-1)){Long g=Xij,T; int J; for(J=j+1;J<*N;J++){T=
 	    labs(AuxGxP(G[i],X[J],d)); if(T) g=Fgcd(g,T);} if(g==D[i]) dia=1;}
 #endif
-	    if(0!=(Xij % D[i])) err=1; printf("%ld ",Xij/D[i]);} puts("");
-     	}
+	    if(0!=(Xij % D[i])) err=1;
+	    printf("%ld ",Xij/D[i]);}
+       puts("");
+     }
 #ifdef	TEST
 	if((dia==0)||err){
 	    int i,j;printf("D=");for(i=0;i<*d;i++)printf("%ld ",D[i]);
 	    printf("   index[%d]=%d\n",*x,*I);for(i=0;i<*d;i++)
 	    {printf("G=");for(j=0;j<*d;j++)printf("%2ld ",G[i][j]);
-	    printf("   G.P="); for(j=0;j<*N;j++)
-		printf("%2ld ",AuxGxP(G[i],X[j],d));puts("");} exit(0);}
+	    printf("   G.P=");
+	    for(j=0;j<*N;j++) printf("%2ld ",AuxGxP(G[i],X[j],d));
+	    puts("");}
+	    exit(0);}
 #endif
 }
 void Aux_Make_Dual(PolyPointList *P, VertexNumList *V, EqList *E)
@@ -1680,7 +1707,8 @@ void PH_Sublat_Polys(char *dbin, int omitFIP, PolyPointList *_P, char sF)
 {     static EqList E; VertexNumList V; int x=0, K, B, I=1; /* index>I only */
      Long *RelPts[POINT_Nmax];DataBase *DB=NULL; if(*dbin)Open_DB(dbin,&DB,0);
      K=((sF!='P')&&(sF!='H')&&(sF!='Q')&&(sF!='B'));    /*  K=='CoverPoly'  */
-     if(('1'<sF)&&(sF<='9')) I=sF-'0'; 	B=(omitFIP==2);	/* 'q' for index >I */
+     if(('1'<sF)&&(sF<='9')) I=sF-'0';
+     B=(omitFIP==2);	/* 'q' for index >I */
      while(Read_H_poly_from_DB_or_inFILE(DB,_P))
      {	Long D[POLY_Dmax],G[POLY_Dmax][POLY_Dmax],PM[VERT_Nmax][VERT_Nmax];
  	int index, N=0; /* if(!Ref_Check(_P,&V,&E)) Print_PPL(_P,""); */
@@ -1691,9 +1719,10 @@ void PH_Sublat_Polys(char *dbin, int omitFIP, PolyPointList *_P, char sF)
 	if(omitFIP==0) for(N=0;N<_P->np;N++) RelPts[N]=_P->x[N];
 	else if(omitFIP<3 )		  		  /* Omit facet-IPs */
 	{   int p; for(p=0;p<_P->np;p++)	        
-	    {	int e, z=0; for(e=0;e<E.ne;e++) 
+	    {	int e, z=0;
+	      for(e=0;e<E.ne;e++) 
 	        if(0==Eval_Eq_on_V(&E.e[e],_P->x[p],_P->n)) z++;
-		if(z>omitFIP) RelPts[N++]=_P->x[p];
+	      if(z>omitFIP) RelPts[N++]=_P->x[p];
 	    }	assert(V.nv<=N);   /* count <E,.>=0; if(n>1) add_to_RelPts; */
 	}
 	else if(omitFIP==3)			   /* Omit all non-vertices */
@@ -1736,7 +1765,8 @@ void V_Sublat_Polys(char mr,char *dbin,char *polyi,char *polyo,
      while(Read_H_poly_from_DB_or_inFILE(DB,_P))
      {	Long D[POLY_Dmax],G[POLY_Dmax][POLY_Dmax];
  	int index, N; assert(Ref_Check(_P,&V,&E)); 
-        for(N=0;N<V.nv;N++) RelPts[N]=_P->x[V.v[N]]; ++x;
+        for(N=0;N<V.nv;N++) RelPts[N]=_P->x[V.v[N]];
+	++x;
 	index=Make_Lattice_Basis(_P->n,N,RelPts,G,D); if(1==index) continue;
 	assert(index>0); if(index>max_order) max_order=index;
 #ifdef	TEST
@@ -1750,7 +1780,7 @@ void V_Sublat_Polys(char mr,char *dbin,char *polyi,char *polyo,
 	}
      }	if(*dbin) Close_DB(DB);
      printf("max_order=%d\n", max_order); Write_List_2_File(polyo,_L); 
-     _L->TIME=time(NULL); printf(ctime(&_L->TIME));
+     _L->TIME=time(NULL); fputs(ctime(&_L->TIME),stdout);
      free(_L);
 }
 void VPHM_Sublat_Polys(char sFlag,char mr,char *dbin,char *polyi,char *polyo, 
@@ -1820,7 +1850,8 @@ void Bin_2_ANF(char *polyi, int max, PolyPointList *_P)
         "%dd  %dv<=%d n<=%d  %dnv  %lld %d %lld %lld  %d %d %d %d",
         d, L.nV, L.nVmax, L.NUCmax,list_num,
         L.nNF,L.nSM,L.nNM,L.NB,  sl_nNF, sl_SM, sl_NM, sl_NB);
-     if(max) printf("  r-max=%d",mc); puts("");
+     if(max) printf("  r-max=%d",mc);
+     puts("");
 }
 
 void Bin_2_ANF_DBsl(char *dbi, int max, int vf, int vt, PolyPointList *_P)
@@ -1871,7 +1902,8 @@ void Bin_2_ANF_DBsl(char *dbi, int max, int vf, int vt, PolyPointList *_P)
         "%dd  %dv<=%d n<=%d  %dnv ... %d %d %d %d",  /* %d %d %d %lld */ 
         d, L.nV, L.nVmax, L.NUCmax,list_num,
         /* L.nNF,L.nSM,L.nNM,L.NB, */ sl_nNF, sl_SM, sl_NM, sl_NB);
-     if(max) printf("  r-max=%d",mc); puts("");
+     if(max) printf("  r-max=%d",mc);
+     puts("");
 }
 
 void Gen_Bin_2_ascii(char *pi,char *dbi,int max,int vf,int vt,PolyPointList *P)
