@@ -866,7 +866,7 @@ void Do_the_Classification(CWS *W, PolyPointList *P, /* char *fn, */
 
   if(rFlag==0) Write_List_2_File(polyo,_NFL); 
   _NFL->TIME=time(NULL); 
-  printf(ctime(&_NFL->TIME));
+  fputs(ctime(&_NFL->TIME),stdout);
   free(_NFL);
 }
 
@@ -1189,7 +1189,7 @@ void Find_Sublat_Polys(char mFlag, char *dbin, char *polyi, char *polyo,
     
   printf("max_order=%d\n", max_order);
   Write_List_2_File(polyo,_NFL); 
-  _NFL->TIME=time(NULL); printf(ctime(&_NFL->TIME));
+  _NFL->TIME=time(NULL); fputs(ctime(&_NFL->TIME),stdout);
   free(_NFL);
 }
 
@@ -1206,6 +1206,7 @@ int irred(PolyPointList *_P)
   int i,j,drop_point[POLY_Dmax];
   VertexNumList V,NV; EqList E;
 
+  for (j=0;j<_P->n;j++) drop_point[j]=0;  /* just to silence the compiler */
   IP_Check(_P,&V,&E);
   for(i=0;i<V.nv;i++){
     
@@ -1267,6 +1268,7 @@ int virred(PolyPointList *_P, EqList *B)
   int i,j,k,drop_point[POLY_Dmax],equal;
   VertexNumList V; EqList E;
   assert(Ref_Check(_P,&V,&E));
+  for (j=0;j<_P->n;j++) drop_point[j]=0;  /* just to silence the compiler */
   /* for(i=0;(i<V.nv);i++) {
     for (j=0;(j<_P->n);j++) fprintf(outFILE,"%d ",(int) _P->x[V.v[i]][j]);
     fprintf(outFILE,"\n");}
@@ -1450,6 +1452,7 @@ int Start_Find_Ref_Subpoly(PolyPointList *_P){
     fprintf(outFILE,"IP_check negative!\n"); exit(0);}
 
   KL.nk=0;
+  for (j=0;j<_P->n;j++) drop_point[j]=0;  /* just to silence the compiler */
 
   for(i=0;i<V.nv;i++) {
     
