@@ -277,7 +277,8 @@ int  main (int narg, char* fn[])
 		  oFlag=atoi(&fn[n][2]);
 		  if (!oFlag) {oFlag=-2; puts("break recursion at RPs");}
 		  else printf("rec-dep<=%d\n",oFlag);}
-                else printf("original lattices only\n");        break;
+                else printf("original lattices only\n");
+		                                                break;
         case 'v': {
           if(fn[n][2]=='f') vf=atoi((fn[n][3]) ? &fn[n][3] : fn[++n]);
           if(fn[n][2]=='t') vt=atoi((fn[n][3]) ? &fn[n][3] : fn[++n]);}
@@ -312,7 +313,8 @@ int  main (int narg, char* fn[])
   else if(HFlag=='t')     Test_Hodge_db(dbin);
   else if(HFlag=='e')     Extract_from_Hodge_db(dbin,x_string,_P);
 #else
-  if(HFlag !=0) {puts("For using Hodge-DB-routines set POLY_Dmax=4!"); exit(0);}
+  else if(HFlag !=0) {
+    puts("For using Hodge-DB-routines set POLY_Dmax=4!"); exit(0);}
 #endif
 
   else if(*dbin&&!*polyo) Add_Polya_2_DBi(dbin,polya,dbout);
