@@ -13,7 +13,7 @@ FILE *inFILE, *outFILE;
 
 typedef struct {  int  u[NFmax];  int nu; } 	CWS_type;
 
-#define OSL (24)  /* opt_string's length */
+#define OSL (26)  /* opt_string's length */
 
 void  PrintCWSUsage(){
   int i;
@@ -25,6 +25,8 @@ void  PrintCWSUsage(){
 "         -w# [L H] make IP weight systems for #-dimensional polytopes.",
 "                   For #>4 the lowest and highest degrees L<=H are required.",
 "             -r/-t make reflexive/transversal weight systems (optional).",
+"         -m# L H   make transverse weight systems for #-dimensional polytopes",
+"                   (fast). The lowest and highest degrees L<=H are required.",
 "         -c#       make combined weight systems for #-dimensional polytopes.",
 "                   For #<=4 all relevant combinations are made by default,",
 "                   otherwise the following option is required:",
@@ -65,6 +67,7 @@ void Print_CWS(CWS *_W);
 void Conv(int narg, char* fn[]);
 void SimplexPointCount(int narg, char* fn[]);
 void Init_IP_Weights(int narg, char* fn[]);
+void Init_moon_Weights(int narg, char* fn[]);
 void Init_IP_CWS(int narg, char* fn[]);
 void IP_Poly_Data(int narg, char* fn[]);
 void Make_CWS_Points(CWS *, PolyPointList *);
@@ -86,6 +89,7 @@ int  main (int narg, char* fn[])
      if(narg==1) {printf("\nFor help type `%s -h'\n\n",fn[0]);exit(0);}
      if((fn[1][0]!='-')||(fn[1][1]=='h')) PrintCWSUsage(/*fn[0]*/);
      else if(fn[1][1]=='w') Init_IP_Weights(narg, fn);
+     else if(fn[1][1]=='m') Init_moon_Weights(narg, fn);
      else if(fn[1][1]=='c') Init_IP_CWS(narg, fn);
      else if(fn[1][1]=='i') IP_Poly_Data(narg, fn);
      else if(fn[1][1]=='N') Npoly2cws(narg, fn);
@@ -408,7 +412,8 @@ void AddHalf()
   while (1){
     for(i=0;i<AMBI_Dmax*(AMBI_Dmax+1);i++)    { 
       char c;
-      while(' '==(c=fgetc(inFILE ))); ungetc(c,inFILE);    /* read blanks */
+      while(' '==(c=fgetc(inFILE )));
+      ungetc(c,inFILE);    /* read blanks */
       if(IsNextDigit()) fscanf(inFILE,"%d",&IN[i]); else break;  }
     if (i==0) break;
     n++;
@@ -421,28 +426,11 @@ void AddHalf()
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 
 
 
 void Make_IP_Weights(int d, int Dmin, int Dmax,int rFlag,int tFlag);
+void MakeMoonWeights(int d, int Dmin, int Dmax);
 void Make_34_Weights(int d, int tFlag);
 void Init_IP_Weights(int narg, char* fn[])
 {    int n=1,d,L=0,H=0,rf=0,tf=0; char *c=&fn[1][2];
@@ -464,6 +452,23 @@ void Init_IP_Weights(int narg, char* fn[])
      }
 }
 
+void Init_moon_Weights(int narg, char* fn[]){
+  int n=1,d,L=0,H=0; char *c=&fn[1][2];
+  if(narg>2) if(c[0]==0) c=fn[++n];
+  if(!IsDigit(c[0])){ puts("-m must be followed by a number");exit(0);}
+  if(POLY_Dmax<(d=atoi(c))){printf("Increase POLY_Dmax to %d\n",d);exit(0);}
+  if(++n<narg) if((fn[n][0]!='-')&&(IsDigit(fn[n][0]))) {
+      L=atoi(fn[n]); assert(++n<narg); assert(IsDigit(fn[n][0]));
+      H=atoi(fn[n]); assert(L<=H); n++;     }
+  n--;
+  while(++n<narg) if(fn[n][0]=='-')     {
+      printf("Illegal option %s\n",fn[n]); exit(0);}     
+  if(++n<narg) {printf("Want %s as output file?\n",fn[n]); exit(0);}
+  if(n<narg) {puts("Too many arguments");exit(0);}
+  if(H) MakeMoonWeights(d+1,L,H);
+  else  {puts("Please give lowest and highest d");exit(0);}
+}
+
 int  VP_2_CWS(Long *V[], int d, int v, CWS *W);
 void Npoly2cws(int narg, char* fn[])
 {    int n=2; CWS W; EqList E; VertexNumList V; Long *X[VERT_Nmax]; FILE *OF;
@@ -474,7 +479,8 @@ void Npoly2cws(int narg, char* fn[])
         if(narg>3) {outFILE=fopen(fn[3],"w"); assert(NULL!=outFILE);}
      }}	OF=outFILE; while(Read_CWS_PP(&W,P))
      {  if(W.N) Die("Only PPL-input in Npoly2cws!");
-	if(!IP_Check(P,&V,&E)) Die("Not IP!"); Sort_VL(&V);
+	if(!IP_Check(P,&V,&E)) Die("Not IP!");
+	Sort_VL(&V);
 	for(n=0;n<V.nv;n++) X[n]=P->x[V.v[n]];
 	if(VP_2_CWS(X,P->n,V.nv,&W)) {Print_CWS(&W);fprintf(outFILE,"\n");}
 	else {outFILE=stderr; Print_PPL(P,"CWS not found"); outFILE=OF;}
@@ -506,13 +512,15 @@ typedef struct { int wnum, N, points[W_Nmax][W_Nmax], nsubsets[W_Nmax-1],
 int  weicomp(weights w1,weights w2,int *_N) 
                                 /* w2-w1, i.e. pos for w1<w2,neg for w1>w2  */
 {    int i=*_N;
-     while((i)&&(w1.n[i]==w2.n[i])) i--;  return w2.n[i]-w1.n[i];
+     while((i)&&(w1.n[i]==w2.n[i])) i--;
+     return w2.n[i]-w1.n[i];
 }
 void insertat(WSaux *X,weights ww, int position)
 {    int i, j;
      for(i=X->wnum-1;i>=position;i--)
        for(j=0;j<=X->N;j++) X->wli[i+1].n[j]=X->wli[i].n[j];
-     for(j=0;j<=X->N;j++) X->wli[position].n[j]=ww.n[j];     X->wnum++;
+     for(j=0;j<=X->N;j++) X->wli[position].n[j]=ww.n[j];
+     X->wnum++;
 }
 
 void addweight(WSaux *X,weights wn)
@@ -660,7 +668,8 @@ void Make_34_Weights(int d, int tFlag)
     W.d=X->wli[i].n[W.N=X->N]; for(j=0;j<X->N;j++)W.w[j]=X->wli[i].n[j]; W.M=0;
     Make_Poly_Points(&W, P); if(Ref_Check(P,&V,&E))
     { int t=Trans_Check(W); char c[5]="  rt"; if(t||!tFlag) {c[3]=(t)?'t':0; 
-	if(Info++) puts(""); WRITE_Weight(&W); printf("%s",c);}}
+	if(Info++) puts("");
+	WRITE_Weight(&W); printf("%s",c);}}
   } fprintf(outFILE,"  #=%d  #cand=%d\n",Info,X->wnum); free(X);
 }
 /*  ==========       End of  ALL  IP  WEIGHTS  in  d <= 4    	==========  */
@@ -682,9 +691,9 @@ int IfIpWWrite(Weight *W, PolyPointList *P, int *rFlag, int *tFlag)
        if(!*tFlag && !*rFlag)
 	 {WRITE_Weight(W); if(r) fprintf(outFILE," r"); 
 #if(TRANS_INFO_FOR_IP_WEIGHTS)
-	  if(Trans_Check(*W)) fprintf(outFILE,"%st", r ? "" : " "); 
+	   if(Trans_Check(*W)) fprintf(outFILE,"%st", r ? "" : " "); 
 #endif
-	 fprintf(outFILE,"\n"); fflush(stdout); return 1;}
+	   fprintf(outFILE,"\n"); fflush(stdout); return 1;}
        return 0;
      } 
      else return 0;
@@ -716,6 +725,144 @@ void Make_IP_Weights(int d, int Dmin, int Dmax, int rFlag, int tFlag)
 {
   MakeIpWeights(d+1, Dmin, Dmax, &rFlag, &tFlag);
 }
+
+
+#define MOONSHINE_CRITERIA (0)
+/* if set to (1), weights are written according to the criteria
+   formulated in IfMoonWWrite, otherwise if they satisfy Trans_Check */
+
+#if(MOONSHINE_CRITERIA)
+
+int IfMoonWWrite(Weight *W, Rat *dmwow, long *nsmallchi, int *stf){
+  /* Write the weights determined by the algorithm;
+     if desired, put in extra conditions like the ones below 
+     (here: chi should be a small multiple of 24)                   */
+  int i, D;
+  Rat chi = rI(0);
+  Rat auxrat;
+  for (D=1; D<=W->d; D++)
+    if (!(W->d % D)){
+      /* sf = Strangefun(W->d / D); */
+      auxrat = rR(stf[W->d / D], W->d);
+      for(i=0; i<W->N; i++)
+	if (!(D * W->w[i] % W->d)) {
+	  auxrat = rP(auxrat, dmwow[i]);
+	  auxrat.N *= -1;}
+      chi = rS(auxrat, chi);}
+  if (chi.D != 1) return 0;
+  /* exit if the weight doesn't satisfy certain desired criteria */
+  if (chi.N % 24) return 0;
+  if (abs(chi.N) > 96) return 1;  
+  (*nsmallchi)++; 
+  WRITE_Weight(W);
+  printf("  chi=%ld\n", chi.N);
+  fflush(0);
+  return 1;
+}
+
+int BlaRout(int quot){/* compute |{(i,j): gcd(i,j,quot)=1}| */
+  int sf = 0, bla, qob;
+  int i,j;
+  for (i=1;i<=quot;i++){
+    bla = Fgcd(i,quot);
+    qob = quot/bla;
+    for (j=1;j<=bla;j++)
+      if (Fgcd(j,bla) == 1) sf += qob;}
+  return sf;
+}
+
+#endif
+
+void RecMoonWeights(Weight *W, int g, int sum, long *npp, long *nintPP1,
+		    long *nintchi, int n, long long *PP1N, long long *PP1D
+#if(MOONSHINE_CRITERIA)
+		    , long *nsmallchi, Rat*dmwow, int *stf
+#endif
+		    ){
+  int wmax=W->d/(W->N-n+1);
+  wmax=min(wmax,W->w[n+1]); 
+  wmax=min(wmax,sum-n);
+  if(n)
+    for(W->w[n]=wmax; (n+1)*W->w[n]>=sum; W->w[n]--){
+#if(MOONSHINE_CRITERIA)
+      dmwow[n] = rR(W->d - W->w[n], W->w[n]);
+#endif
+      /*PP1[n] = rP(dmwow[n], PP1[n+1]);*/
+      PP1N[n] = PP1N[n+1] * (long long) (W->d - W->w[n]); assert(PP1N[n]>0);
+      PP1D[n] = PP1D[n+1] * (long long) W->w[n];
+      RecMoonWeights(W, Fgcd(g,W->w[n]), sum-W->w[n], npp, nintPP1, nintchi,
+		     n-1, PP1N, PP1D
+#if(MOONSHINE_CRITERIA)
+		     , nsmallchi, dmwow, stf
+#endif
+		     );}
+  else if (1 == Fgcd(g,sum)){
+    W->w[0]=sum;
+    /*PP1[n] = rP(dmwow[n], PP1[n+1]);*/
+    PP1N[n] = PP1N[n+1] * (long long) (W->d - W->w[n]);
+    PP1D[n] = PP1D[n+1] * (long long) W->w[n];
+    (*npp)++;
+    /*if (PP1->D != 1) return;*/
+    if (PP1N[0] % PP1D[0]) return;
+    if (PP1N[n]/PP1N[n+1] != W->d - W->w[n]) return;
+    (*nintPP1)++;
+#if(MOONSHINE_CRITERIA)
+    dmwow[n] = rR(W->d - W->w[n], W->w[n]);
+    if(IfMoonWWrite(W, dmwow, nsmallchi, stf)) (*nintchi)++;
+#else
+    if(Trans_Check(*W)){
+      WRITE_Weight(W); fprintf(outFILE,"\n");fflush(stdout); (*nintchi)++;}
+#endif
+  }
+}
+
+void MakeMoonWeights(int N, int from_d, int to_d){
+  /* Fast routine for creating candidates for transverse weight systems;
+     conditions: Poincare-polynomial at t=1 integer, chi integer */
+  long int npp=0, nintPP1=0, nintchi=0;
+  Weight W;
+  /* Rat PP1[W_Nmax]; */   /* Poincare polynomial evaluated at t=1 */
+  long long PP1N[W_Nmax], PP1D[W_Nmax];
+#if(MOONSHINE_CRITERIA)
+  long int nsmallchi=0, i;
+  Rat dmwow[W_Nmax]; /* dmwow[i] = rR(W.d-W.w[i], W.w[i]); "d minus w over w" */
+  int *stf = (int *) malloc((to_d +1) * sizeof(int));
+  for (i=1; i<=to_d; i++) stf[i] = BlaRout(i);
+#endif
+  assert((N<=W_Nmax)&&(N<POLY_Dmax+2));
+  W.N=N;
+  W.M=0;
+  for(W.d=from_d; W.d<=to_d; W.d++){
+#if(MOONSHINE_CRITERIA)
+    /* if results are rare, create output to show that the program is still
+       doing something  */
+    if (W.d>607) printf("d=%d\n",W.d);
+    fflush(0);
+#endif
+    for(W.w[N-1]=W.d/2; W.d <= N*W.w[N-1]; W.w[N-1]--){
+      /*PP1[N-1] = rR(W.d-W.w[W.N-1], W.w[W.N-1]);*/
+      PP1N[N-1] = W.d-W.w[W.N-1];
+      PP1D[N-1] = W.w[W.N-1];
+#if(MOONSHINE_CRITERIA)
+     dmwow[N-1] = rR(W.d-W.w[W.N-1], W.w[W.N-1]);
+#endif
+     RecMoonWeights(&W, Fgcd(W.d, W.w[W.N-1]), W.d-W.w[W.N-1], &npp, &nintPP1,
+		     &nintchi, N-2, PP1N, PP1D
+#if(MOONSHINE_CRITERIA)
+		     , &nsmallchi, dmwow, stf
+#endif
+		     );}}
+#if(MOONSHINE_CRITERIA)
+  fprintf(outFILE,"#partitions=%ld #intPP1=%ld #intchi=%ld #smallchi=%ld\n",
+	  npp, nintPP1, nintchi, nsmallchi);
+#else
+  fprintf(outFILE,"#partitions=%ld #intPP1=%ld #trans=%ld\n",
+	  npp, nintPP1, nintchi);
+#endif
+  exit(0);
+}
+
+
 	/* ----------   LG/transversal stuff  ------------ */
 #define  ALLOWHALF	(1)		      /* i.e. trivial LG potentials */
 #define  CHAT		(0)			/* 3 ... for positive c_1 */
@@ -802,7 +949,8 @@ void T_Insertat(T_weight ww, int position,T_aux *X)
 {    int i, j;
      for(i=X->wnum-1;i>=position;i--)
          for(j=0;j<X->wli[i][0]+2;j++) X->wli[i+1][j]=X->wli[i][j];
-     for(j=0;j<ww[0]+2;j++) X->wli[position][j]=ww[j]; X->wnum++;
+     for(j=0;j<ww[0]+2;j++) X->wli[position][j]=ww[j];
+     X->wnum++;
 }
 void T_Addweight(T_weight win,T_aux *X)
 {    int i, p, n0, n1; T_weight wn; for(i=0;i<*win+2;i++) wn[i]=win[i];
@@ -1448,11 +1596,13 @@ void Make_IP_CWS(int narg, char* fn[])
       break;
     if(fn[n][1] == 'c'){
       if((fn[n][2]==0) && (narg>n+1)) a=fn[++n]; else a=&fn[n][2];
-      if(!IsDigit(*a)) Die("after -c there must be a digit!"); d = atoi(a);
+      if(!IsDigit(*a)) Die("after -c there must be a digit!");
+      d = atoi(a);
     }
     if(fn[n][1] == 'n'){ 
       if((fn[n][2]==0) && (narg>n+1)) a=fn[++n]; else a=&fn[n][2];
-      if(!IsDigit(*a)) Die("after -n there must be a digit!"); nF = atoi(a);
+      if(!IsDigit(*a)) Die("after -n there must be a digit!");
+      nF = atoi(a);
       n++; break;
     }
     if(fn[n][1] == 't') PrintCWSTypes();
@@ -1463,7 +1613,8 @@ void Make_IP_CWS(int narg, char* fn[])
     infile[i] = fn[n];
     n++;
   }
-  if((narg > n) && (fn[n][0] != '-')) Die("too many infiles!"); n--; t.nu=0;
+  if((narg > n) && (fn[n][0] != '-')) Die("too many infiles!");
+  n--; t.nu=0;
   while (narg > ++n) {
     if(fn[n][0] != '-') break;
     if(fn[n][1] == 't'){ 
@@ -1695,7 +1846,8 @@ void Conv(int narg, char* fn[])
   while ((narg > ++n) && (fn[n][0] == '-')){
     if(fn[n][1] == 'p'){
       if(fn[n][2]!=0){ a=&fn[n][2];
-      if(!IsDigit(*a)) Die("after -c there must be a digit!"); x=atoi(a);}
+      if(!IsDigit(*a)) Die("after -c there must be a digit!");
+      x=atoi(a);}
     }
   }
   for(i = 0; i < nF; i++){
@@ -1744,8 +1896,9 @@ Long NP_use_lat(EqList *_E, PolyPointList *_P)
     
     td_Print_EL(_E,&_P->n,0,"");
     system(command);outFILE=fopen("zzL.tmp1","r");
-    while((fscanf(outFILE,"%d",&tmp))!=EOF);fclose(outFILE); return tmp;
-    
+    while((fscanf(outFILE,"%d",&tmp))!=EOF);
+    fclose(outFILE);
+    return tmp;
 }
 Long L_Point_Count(Weight *W,PolyPointList *P,VertexNumList *V,EqList *E){
   int i,j,d; 
@@ -1775,5 +1928,6 @@ void SimplexPointCount(int narg, char* fn[])
   while(Read_Weight(&W)){int n; Long np= L ? L_Point_Count(&W,P,&V,E) :
     W_Point_Count(&W,P,&V,E); 
     if(np<=SIMPLEX_POINT_Nmax){printf("%d",W.d); 
-      for(n=0;n<W.N;n++)printf(" %ld",W.w[n]);printf(" N:%ld\n",np);fflush(0);}}
+      for(n=0;n<W.N;n++) printf(" %ld",W.w[n]);
+      printf(" N:%ld\n",np);fflush(0);}}
   free(P); free(E); }
