@@ -2,8 +2,6 @@
 /*  ==========                                                  ==========  */
 /*  ==========                P O L Y . C                       ==========  */
 /*  ==========                                                  ==========  */
-/*  ==========               January 2011                       ==========  */
-/*  ==========                                                  ==========  */
 /*  ======================================================================  */
 
 /*
@@ -16,7 +14,8 @@
 
 #include "Global.h"
 #include "LG.h"
-#define OSL (39)  /* opt_string's length */
+#define OSL (41)  /* opt_string's length */
+
 
 FILE *inFILE, *outFILE;
 
@@ -36,6 +35,8 @@ void  PrintUsage(char *c){
   "a  all of the above except h,f      ",
   "l  LG-`Hodge numbers' from single weight input                   ",
   "r  ignore non-reflexive input       ",
+  "o  ignore non-IP input       ",
+  "q  quick version of og, incompatible with other options",   
   "D  dual polytope as input (ref only)",
   "n  do not complete polytope or calculate Hodge numbers        ",
   "i  incidence information            ",
@@ -81,7 +82,7 @@ typedef	struct 	{int p[SYM_Nmax][VERT_Nmax];}		VPermList;
 int main (int narg, char* fn[]){
   int n=0, k, FilterFlag=0, lg=0, s=0, i=0, m=0, p=0, v=0, e=0, d=0, t=0, z=0,
     S=0, N=0, I=0, r=0, nc=0, g=0, D=0, IP, R, Tr, T=0, PS=0, VS=0, CD=0, ZS=1,
-    A=0, B=0, G=0, F=0, U=0, dd=0, Einstein=0;
+    A=0, B=0, G=0, F=0, U=0, dd=0, Einstein=0, o=0, q=0;
   char c; 
   CWS *CW=(CWS *) malloc(sizeof(CWS));
   Weight W;
@@ -95,6 +96,7 @@ int main (int narg, char* fn[]){
   FaceInfo *FI=NULL;
   PairMat *PM = (PairMat *) malloc(sizeof(PairMat)),
          *DPM = (PairMat *) malloc(sizeof(PairMat));
+  C5stats C5S;
 
   if((CW==NULL)||(E==NULL)||(_P==NULL)||(DE==NULL)||(_DP==NULL)
 	||(PM==NULL)||(DPM==NULL)) {
@@ -130,6 +132,8 @@ int main (int narg, char* fn[]){
       else if(c=='N') N=1;
       else if(c=='T') T=1;
       else if(c=='r') r=1;
+      else if(c=='o') o=1;
+      else if(c=='q') q=1;
       else if(c=='n') nc=1;
       else if(c=='P') PS=1;
       else if(c=='V') VS=1;
@@ -141,7 +145,8 @@ int main (int narg, char* fn[]){
       else {printf("Unknown option '-%c'; use -h for help\n",c); exit(0);}}}
   n--;
 
-  if(s+i+I+m+p+v+e+d+t+S+N+T+PS+VS+CD+G+A+B+F+z==0) g=1; VH.sts=(lg==2);
+  if(s+i+I+m+p+v+e+d+t+S+N+T+PS+VS+CD+G+A+B+F+z==0) g=1;
+  VH.sts=(lg==2);
   if ((U==1)&&(CD==1)&&(s+i+I+m+p+v+e+d+t+S+N+T+PS+VS+G+A+B+F+z==0)) g=1;
   if(g+lg+p+d+PS+CD==0) nc=1; /* don't need completion of points */
   if((T==1)&&(B+U+lg+g+s+i+I+m+p+v+e+d+t+S+N+PS+VS+(1-ZS)==0)){ puts(
@@ -157,9 +162,15 @@ int main (int narg, char* fn[]){
   if(i){
     FI=(FaceInfo *) malloc(sizeof(FaceInfo));
     if (FI==NULL) {puts("Unable to allocate space for FaceInfo FI"); exit(0);}}
-
+  if(q) Initialize_C5S(&C5S, _P->n); // Initialize statistics
   if(Einstein) Einstein_Metric(CW,_P,&V,E);
   while(lg ? Read_W_PP(&W,_P) : Read_CWS_PP(CW,_P)) {
+    if(q) {
+      FaceInfo FI;
+      if (!QuickAnalysis(_P, &BH, &FI)) {C5S.n_nonIP++; continue;} //non-IP
+      Print_CWH(CW, &BH);
+      Update_C5S(&BH, FI.nf, CW->W[0], &C5S);
+      continue;}
     if(T) {
       if (CW->nw) {
 	puts("Please do not use weight input with the -T option"); continue;}
@@ -174,6 +185,7 @@ int main (int narg, char* fn[]){
 	for (k=0;k<_P->np;k++) V.v[k]=k;
 	V.nv=_P->np;      }
       else R=EL_to_PPL(E, _DP, &_P->n);}
+    else if (o&&!IP) continue;
     if (D&&!R) {fprintf(outFILE,"Input not reflexive!\n"); continue;}
     if (r&&!R) continue;
     Sort_VL(&V);
@@ -223,8 +235,8 @@ int main (int narg, char* fn[]){
     if(B) {
       Long vB[POLY_Dmax],Z; int j;
       Long vol=LatVol_Barycent(_P,&V,vB,&Z); printf("vol=%ld, baricent=(",vol); 
-      for(j=0;j<_P->n;j++)printf("%s%ld",j?",":"",vB[j]); printf(")/%ld\n",Z);
-      if(CD) IPs_degD(_P,&V,E,CD);}
+      for(j=0;j<_P->n;j++) printf("%s%ld",j?",":"",vB[j]);
+      printf(")/%ld\n",Z); if(CD) IPs_degD(_P,&V,E,CD);}
     if(F) { 
       int j, cc;
       Long VM[POLY_Dmax][VERT_Nmax];
@@ -236,5 +248,6 @@ int main (int narg, char* fn[]){
       Make_ANF(_P,&V,E,ANF); 
       Print_Matrix(ANF, _P->n, V.nv,"Affine normal form");}
     fflush(outFILE);     }
+  if(q) Print_C5S(&C5S);
   return 0;
 }
